@@ -1,5 +1,5 @@
 /****************************************************
-* unit:    strings           release 0.23           *
+* unit:    strings           release 0.25           *
 * purpose: general manipulation with text strings   *
 * Licency: GPL or LGPL                              *
 * Copyright: (c) 1998-2021 Jaroslav Fojtik          *
@@ -138,12 +138,12 @@ FastExit:size = maxlen = 0;
 }
 
 
+#ifdef USE_TEMP_STRINGS
 /// Create a new string and steal the content of the donor.
 string::string(temp_string &s)
 {
-string *ps = &s;	// Workaround failure to access members
- ch=ps->ch; size=ps->size; maxlen=ps->maxlen;
- ps->ch=NULL; ps->size=ps->maxlen=0;
+ ch=s.ch; size=s.size; maxlen=s.maxlen;
+ s.ch=NULL; s.size=s.maxlen=0;
 }
 
 
@@ -155,10 +155,10 @@ string *ps = &s;	// Workaround failure to access members
 /// string result_slow(GetString());	// This will duplicate temporary object
 string::string(temp_string *s)
 {
-string *ps = s;		// Workaround failure to access members
- ch=ps->ch; size=ps->size; maxlen=ps->maxlen;
- ps->ch=NULL; ps->size=ps->maxlen=0;
+ ch=s->ch; size=s->size; maxlen=s->maxlen;
+ s->ch=NULL; s->size=s->maxlen=0;
 }
+#endif
 
 
 /// Allocates 'i+1' bytes and copy maximally i characters from str.
@@ -172,8 +172,8 @@ string::string(const char *str, int i)
         return;
         }
  maxlen--;
+ memcpy(ch,str,i);
  ch[i]=0;
- strncpy(ch,str,i);
  size=strlen(ch);
 }
 
@@ -283,7 +283,7 @@ char str[24];
 /// Operator for filling string from char *
 string &string::operator=(const char *str)
 {
-int len;
+unsigned len;
 
  if((len=::StrLen(str))==0)
 	{
@@ -370,66 +370,66 @@ return(*this);
 //--- family of     Addind Strings   -------
 temp_string operator+(const string & s1, const string & s2)
 {
- if(s2.size==0) return(s1);
- if(s1.size==0) return(s2);
+ if(s2.size==0) return(temp_string(s1.ch,s1.size));
+ if(s1.size==0) return(temp_string(s2.ch,s2.size));
 
- temp_string tmp(s1.size+s2.size);
+ string tmp(s1.size+s2.size);
  if(tmp.ch==NULL)
 	{
 	RaiseError(StringsId|No_Memory,&tmp);
-	return(tmp);	//no memory, zero or wrong size
+	return temp_string();		//no memory, zero or wrong size
 	}
  if(((long)s1.size+(long)s2.size)>(long)tmp.maxlen)
 	{
-	return(tmp);	//nasty int overflow
+	return(temp_string(tmp));	//nasty int overflow
 	}
 
  memcpy(tmp.ch,s1.ch,s1.size);
  memcpy(tmp.ch+s1.size,s2.ch,s2.size+1);
  tmp.size = s1.size + s2.size;
-return(tmp);
+return(temp_string(tmp));
 }
 
 
 temp_string operator+(const string & s1, const char *str)
 {
 unsigned len;
- if(str==NULL) return(s1);
+ if(str==NULL) return(temp_string(s1.ch,s1.size));
  len=strlen(str);	//NULL is fixed above
- if(len==0) return(s1);
+ if(len==0) return(temp_string(s1.ch,s1.size));
 
- temp_string tmp(s1.size+len);
+ string tmp(s1.size+len);
  if(tmp.ch==NULL || ((long)s1.size+(long)len)>(long)tmp.maxlen)
 	{
 	RaiseError(StringsId|No_Memory,&tmp);
-	return(tmp);	//no memory, zero or wrong size
+	return temp_string();	//no memory, zero or wrong size
 	}
 
  if(s1.size>0) memcpy(tmp.ch,s1.ch,s1.size);
  memcpy(tmp.ch+s1.size,str,len+1);
  tmp.size = s1.size+len;
-return(tmp);
+return(temp_string(tmp));
 }
 
 temp_string operator+ (const char *str, const string & s2)
 {
 unsigned len;
- if(str==NULL) return(s2);
+ if(str==NULL) return(temp_string(s2.ch,s2.size));
  len=strlen(str);
- if(len==0) return(s2);
+ if(len==0) return(temp_string(s2.ch,s2.size));
  if(s2.size<=0) return(str);
 
- temp_string tmp(s2.size+len);
+ string tmp(s2.size+len);
  if(tmp.ch==NULL || ((long)s2.size+(long)len)>(long)tmp.maxlen)
 	{
 	RaiseError(StringsId|No_Memory,&tmp);
-	return(tmp);	//no memory, zero or wrong size
+	return temp_string();	//no memory, zero or wrong size
 	}
 
  memcpy(tmp.ch,str,len+1);
  memcpy(tmp.ch+len,s2.ch,s2.size+1);
  tmp.size = len + s2.size;
- return(tmp);
+ return(temp_string(tmp));
 }
 
 
@@ -437,11 +437,11 @@ temp_string operator+ (const string & s, char c)
 {
  if(s.size==0) return(temp_string(c));
 
- temp_string tmp(s.size+1);
+ string tmp(s.size+1);
  if(tmp.ch==NULL)
 	{
 	RaiseError(StringsId|No_Memory,&tmp);
-	return(tmp);	//no memory or zero size
+	return temp_string();	//no memory or zero size
 	}
 
  memcpy(tmp.ch,s.ch,s.size);
@@ -449,27 +449,27 @@ temp_string operator+ (const string & s, char c)
  tmp.size = s.size+1;
  tmp.ch[tmp.size]=0;
 
- return(tmp);
+ return(temp_string(tmp));
 }
 
 
 temp_string operator+ (char c, const string & s)
 {
- if(c==0) return(s);
+ if(c==0) return(temp_string(s.ch,s.size));
  if(length(s)==0) return(temp_string(c));
 
- temp_string tmp(s.size+1);
+ string tmp(s.size+1);
  if(tmp.ch==NULL)
 	{
 	RaiseError(StringsId|No_Memory,&tmp);
-	return(tmp);	//no memory or zero size
+	return temp_string();	//no memory or zero size
 	}
 
  tmp.ch[0]=c;
  tmp.ch[1]=0;
  tmp.size = s.size+1;
  memcpy(tmp.ch+1,s.ch,tmp.size);
- return(tmp);
+ return(temp_string(tmp));
 }
 
 
@@ -552,12 +552,12 @@ char str[24];
 
 temp_string multiply(const string& s, unsigned n)
 {
- temp_string tmp(n*length(s));
- if(tmp.ch==NULL) return(tmp);	    //memory exhausted or n==0
+ string tmp(n*length(s));
+ if(tmp.ch==NULL) return temp_string();	    //memory exhausted or n==0
 
  while(n-->0)
 	tmp += s;
- return tmp;
+ return temp_string(tmp);
 }
 
 
@@ -600,7 +600,7 @@ unsigned int Length;
  ch[maxlen] = 0;
  if((size=::StrLen(ch))!=Length)
      ret = StringsId | Bad_Length;
- if((c!=0)&&(size==maxlen))
+ if(size==maxlen && c!=0)
      ret = StringsId | Unterminated;
 return(ret);
 }
@@ -609,22 +609,93 @@ return(ret);
 
 ///////////Speedup class temp_string////////////////
 
+#ifdef USE_TEMP_STRINGS
+temp_string::temp_string(char c)
+{
+ maxlen = FIX_ALLOC(2);
+ if((ch=(char *)malloc(maxlen))==NULL)
+	{
+	maxlen = size = 0;
+	RaiseError(StringsId|No_Memory,this); //Memory Exhausted
+        return;
+	}
+ maxlen--;
+ size = 1;
+ *ch = c;
+ ch[1] = 0;
+}
+
+
+temp_string::temp_string(const char *str)
+{
+ if(str==NULL)
+            {
+FastExit:   ch = NULL;
+FastExit2:  size = maxlen = 0;
+            return;
+            }
+
+ if((size=strlen(str))==0) goto FastExit;
+ maxlen = FIX_ALLOC(size+1);
+ if((ch=(char *)malloc(maxlen)) == NULL)
+	      {
+	      RaiseError(StringsId|No_Memory,this); //Memory Exhausted
+              goto FastExit2;
+              }
+ maxlen--;
+ memcpy(ch,str,size+1);	//strncpy(ch,str,maxlen+1);
+}
+
+
+/// Allocates 'i+1' bytes and copy maximally i characters from str.
+temp_string::temp_string(const char *str, int i)
+{
+ maxlen = FIX_ALLOC(i+1);
+ if((ch=(char *)malloc(maxlen)) == NULL)
+	{
+	size = maxlen = 0;
+	RaiseError(StringsId|No_Memory,this); //Memory Exhausted
+        return;
+        }
+ maxlen--;
+ ch[i]=0;
+ strncpy(ch,str,i);
+ size = strlen(ch);
+}
+
+
 string &string::operator=(temp_string &s)
 {
-string *ps = &s;
- if(ps->size==0)
+ if(s.size==0)
+	{
+	size = 0;
+	if(maxlen>0) *ch=0;
+	return(*this);
+	}
+ if(ch)
+   if(maxlen>0 || size==0) free(ch);
+ ch=s.ch; size=s.size; maxlen=s.maxlen;
+ s.ch=NULL; s.size=s.maxlen=0;
+return(*this);
+}
+
+
+temp_string &temp_string::operator=(temp_string &s)
+{
+ if(s.size==0)
 	{
 	size=0;
 	if(maxlen>0) *ch=0;
 	return(*this);
 	}
  if(ch)
-   if((maxlen>0)||(size==0)) free(ch);
- ch=ps->ch; size=ps->size; maxlen=ps->maxlen;
- ps->ch=NULL; ps->size=ps->maxlen=0;
+   if(maxlen>0 || size==0) free(ch);
+ ch=s.ch; size=s.size; maxlen=s.maxlen;
+ s.ch=NULL; s.size=s.maxlen=0;
 return(*this);
 }
 
+#endif
 
 ////////////////////////////////////////////////////////////////
 //Related procedures for class String
@@ -645,18 +716,19 @@ temp_string ToUpper(const char *str)
 {
 unsigned int len=::StrLen(str);
 char *buff;
-temp_string s(len);
+string s(len);
 
- buff=s();
+ buff = s();
  if(buff!=NULL)
    {
    while(*str)
 	{
 	*buff++ = toupper((unsigned char)*str++);
 	}
-   s.SetSize(len);
+   s.size = len;
+   s.ch[len] = 0;
    }
-return(s);
+return(temp_string(s));
 }
 
 
@@ -676,7 +748,7 @@ temp_string ToLower(const char *str)
 {
 unsigned int len=::StrLen(str);
 char *buff;
-temp_string s(len);
+string s(len);
 
   buff = s();
   if(buff!=NULL)
@@ -685,9 +757,10 @@ temp_string s(len);
 	{
 	*buff++ = tolower((unsigned char)*str++);
 	}
-    s.SetSize(len);
+    s.size = len;
+    s.ch[len] = 0;
     }
-return(s);
+return(temp_string(s));
 }
 
 
@@ -721,11 +794,11 @@ temp_string del(const string &s, int from, int len)
 	return temp_string();
 	}
 
- temp_string tmp((unsigned)(length(s)-len));
+ string tmp((unsigned)(length(s)-len));
  memmove(tmp.ch,s.ch,from);
  memmove(tmp.ch+from,s.ch+from+len,length(s)-from-len+1);
  tmp.size = length(s)-len;
-return(tmp);
+return(temp_string(tmp));
 }
 
 
@@ -735,15 +808,15 @@ temp_string insert(const string &s, const string &s2, int position)
 	{
 	return temp_string();
 	}
- if(length(s)==0) return(s2);
- if(length(s2)==0) return(s);
+ if(length(s)==0) return(temp_string(s2.ch,s2.size));
+ if(length(s2)==0) return(temp_string(s.ch,s.size));
 
- temp_string tmp((unsigned)(length(s)+length(s2)));
+ string tmp((unsigned)(length(s)+length(s2)));
  memmove(tmp.ch,s.ch,position);
  memmove(tmp.ch+position,s2.ch,length(s2));
  memmove(tmp.ch+position+length(s2),s.ch+position,length(s)-position+1);
  tmp.size = length(s)+length(s2);
-return(tmp);
+return(temp_string(tmp));
 }
 
 
@@ -754,13 +827,13 @@ temp_string replacesubstring(const string & s, const string & substring, const s
 char *newptr,*ptr;
 char c;
 
- if(substring=="" || length(s)<length(substring)) return(s);
+ if(substring=="" || length(s)<length(substring)) return(temp_string(s.ch,s.size));
 
- ptr=s();
+ ptr = s();
  newptr = StrStr(ptr,substring());
- if(newptr==NULL) return(s);
+ if(newptr==NULL) return(temp_string(s.ch,s.size));
 
- temp_string tmp;
+ string tmp;
  do {
     c=*newptr;
     *newptr=0;
@@ -774,7 +847,7 @@ char c;
     } while((newptr=StrStr(ptr,substring())) != NULL);
  tmp += ptr;
 
-return(tmp);
+return(temp_string(tmp));
 }
 
 
@@ -784,15 +857,15 @@ char *newptr,*ptr;
 char c;
 int substrlen;
 
- if(substring==NULL) return(s);
+ if(substring==NULL) return(temp_string(s.ch,s.size));
  substrlen=strlen(substring);
- if(substrlen==0 || length(s)<substrlen) return(s);
+ if(substrlen==0 || length(s)<substrlen) return(temp_string(s.ch,s.size));
 
- ptr=s();
- newptr=StrStr(ptr,substring);
- if(newptr==NULL) return(s);
+ ptr = s();
+ newptr = StrStr(ptr,substring);
+ if(newptr==NULL) return(temp_string(s.ch,s.size));
 
- temp_string tmp;
+ string tmp;
  do {
     c=*newptr;
     *newptr=0;
@@ -806,7 +879,7 @@ int substrlen;
     } while((newptr=StrStr(ptr,substring)) != NULL);
  tmp += ptr;
 
-return(tmp);
+return(temp_string(tmp));
 }
 
 
