@@ -1,7 +1,7 @@
 /*
    cole - A free C OLE library.
    Copyright 1998, 1999  Roberto Arturo Tena Sanchez
-   Copyright 2002, 2007  Jaroslav Fojtik
+   Copyright 2002, 2023  Jaroslav Fojtik
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU Lesser General Public License as published
@@ -32,6 +32,11 @@
 #include "cole.h"
 #include <assert.h>
 
+#if defined(_MSC_VER) && _MSC_VER<=1500
+ // Nasty bug in Visual Studio: https://social.msdn.microsoft.com/Forums/vstudio/en-US/259c9af3-0168-47cd-a99c-cc2a78ebe777/tmpnam-refers-to-c-instead-of-current-working-directory?forum=vcgeneral
+ char *tmpnamFix(char *s);
+ #define tmpnam tmpnamFix
+#endif
 
 
 #define ENTRYCHUNK 20	/* number of entries in root_list and sbd_list
@@ -42,18 +47,18 @@
 typedef struct
   {
   FILE *input;
-  U8 *Block;
-  U8 *Blockx;
-  U8 *BDepot, *SDepot, *Root;
+  uint8_t *Block;
+  uint8_t *Blockx;
+  uint8_t *BDepot, *SDepot, *Root;
   pps_entry *pps_list;
-  U32 num_of_pps;
+  uint32_t num_of_pps;
   FILE *sbfile;
   /* sbfilename is stored in *_sbfilename instead -- cole 2.0.0 */
   /* static char sbfilename[L_tmpnam]; */
-  U32 *sbd_list;
-  U32 *root_list;
+  uint32_t *sbd_list;
+  uint32_t *root_list;
 
-  U32 *last_next_link_visited;
+  uint32_t *last_next_link_visited;
   } ole_internal;
 
 
@@ -64,7 +69,7 @@ typedef struct
 /* not sure if it is safe declare last_next_link_visited
    inside reorder_pps_tree function */
 
-static int reorder_pps_tree (pps_entry * node, U16 level,ole_internal *o)
+static int reorder_pps_tree (pps_entry * node, uint16_t level,ole_internal *o)
 {
   /* NOTE: in next, previous and dir link,
      0xffffffff means point to nowhere (NULL) */
@@ -76,7 +81,7 @@ static int reorder_pps_tree (pps_entry * node, U16 level,ole_internal *o)
   {
     if (node->dir > o->num_of_pps || !o->pps_list[node->dir].name[0])
       return 0;
-    else if (!reorder_pps_tree (&o->pps_list[node->dir], (U16)(level + 1),o))
+    else if (!reorder_pps_tree (&o->pps_list[node->dir], (uint16_t)(level + 1),o))
       return 0;
   }
 
@@ -141,17 +146,17 @@ static void ends(ole_internal *o)
 }
 
 
-int cpp_OLEdecode (char *OLEfilename, COLEFS *ole, U16 max_level)
+int cpp_OLEdecode (char *OLEfilename, COLEFS *ole, uint16_t max_level)
 {
   ole_internal o;
   int c;
-  U32 num_bbd_blocks;
-  U32 num_xbbd_blocks;
-  U32 bl;
-  U32 i, j, len;
-  U8 *s, *p, *t;
+  uint32_t num_bbd_blocks;
+  uint32_t num_xbbd_blocks;
+  uint32_t bl;
+  uint32_t i, j, len;
+  uint8_t *s, *p, *t;
   long FilePos;
-  /* FilePos is long, not U32, because second argument of fseek is long */
+  /* FilePos is long, not uint32_t, because second argument of fseek is long */
 
   /* initialize static variables */
   o.input = o.sbfile = NULL;
@@ -182,7 +187,7 @@ int cpp_OLEdecode (char *OLEfilename, COLEFS *ole, U16 max_level)
 
   /* read header block */
   verbose ("read header block");
-  o.Block = (U8 *) malloc (0x0200);
+  o.Block = (uint8_t *) malloc (0x0200);
   test_exitf (o.Block != NULL, 10, ends(&o));
   fread (o.Block, 0x0200, 1, o.input);
   test_exitf (!ferror (o.input), 5, ends(&o));
@@ -200,7 +205,7 @@ int cpp_OLEdecode (char *OLEfilename, COLEFS *ole, U16 max_level)
   num_xbbd_blocks = fil_sreadU32 (o.Block + 0x48);
   verboseU32 (num_bbd_blocks);
   verboseU32 (num_xbbd_blocks);
-  o.BDepot = (U8*)malloc (0x0200 * (num_bbd_blocks + num_xbbd_blocks));
+  o.BDepot = (uint8_t*)malloc (0x0200 * (num_bbd_blocks + num_xbbd_blocks));
   test_exitf (o.BDepot != NULL, 10, ends(&o));
   ole->BDepot = o.BDepot;
   s = o.BDepot;
@@ -218,7 +223,7 @@ int cpp_OLEdecode (char *OLEfilename, COLEFS *ole, U16 max_level)
       s += 0x0200;
     }
 
-  o.Blockx = (U8 *) malloc (0x0200);
+  o.Blockx = (uint8_t *) malloc (0x0200);
   test_exitf (o.Blockx != NULL, 10, ends(&o));
   bl = fil_sreadU32 (o.Block + 0x44);
   for (i = 0; i < num_xbbd_blocks; i++)
@@ -252,7 +257,7 @@ int cpp_OLEdecode (char *OLEfilename, COLEFS *ole, U16 max_level)
 
   /* extract the sbd block list */
   verbose ("extract small block depot (sbd) block list");
-  o.sbd_list = (U32 *)malloc (ENTRYCHUNK * 4);
+  o.sbd_list = (uint32_t *)malloc (ENTRYCHUNK * 4);
   test_exitf (o.sbd_list != NULL, 10, ends(&o));
   o.sbd_list[0] = fil_sreadU32 (o.Block + 0x3c);
   /* -2 signed long int == 0xfffffffe unsinged long int */
@@ -262,8 +267,8 @@ int cpp_OLEdecode (char *OLEfilename, COLEFS *ole, U16 max_level)
       /* if memory allocated in sbd_list is all used, allocate more memory */
       if (!(len % ENTRYCHUNK))
 	{
-	  U32 *newspace;
-	  newspace = (U32 *)realloc (o.sbd_list,
+	  uint32_t *newspace;
+	  newspace = (uint32_t *)realloc (o.sbd_list,
 			      (1 + len/ENTRYCHUNK) * ENTRYCHUNK * 4);
 	  test_exitf (newspace != NULL, 10, ends(&o));
 	  o.sbd_list = newspace;
@@ -289,7 +294,7 @@ int cpp_OLEdecode (char *OLEfilename, COLEFS *ole, U16 max_level)
   else
     {
       verbose ("read small block depot (sbd)");
-      o.SDepot = (U8 *)malloc (0x0200*len);
+      o.SDepot = (uint8_t *)malloc (0x0200*len);
       test_exitf (o.SDepot != NULL, 10, ends(&o));
       s = o.SDepot;
       for (i = 0; i < len; i++)
@@ -308,7 +313,7 @@ int cpp_OLEdecode (char *OLEfilename, COLEFS *ole, U16 max_level)
 
   /* extract the root block list */
   verbose ("extract root block depot (root) block list");
-  o.root_list = (U32 *)malloc(ENTRYCHUNK*4);
+  o.root_list = (uint32_t *)malloc(ENTRYCHUNK*4);
   test_exitf (o.root_list != NULL, 10, ends(&o));
   o.root_list[0] = fil_sreadU32 (o.Block + 0x30);
   for (len = 1; o.root_list[len - 1] != 0xfffffffeUL; len++)
@@ -317,8 +322,8 @@ int cpp_OLEdecode (char *OLEfilename, COLEFS *ole, U16 max_level)
       /* if memory allocated in root_list is all used, allocate more memory */
       if (!(len % ENTRYCHUNK))
 	{
-	  U32 *newspace;
-	  newspace = (U32 *)realloc (o.root_list,
+	  uint32_t *newspace;
+	  newspace = (uint32_t *)realloc (o.root_list,
 			      (1 + len / ENTRYCHUNK) * ENTRYCHUNK * 4);
 	  test_exitf (newspace != NULL, 10, ends(&o));
 	  o.root_list = newspace;
@@ -331,7 +336,7 @@ int cpp_OLEdecode (char *OLEfilename, COLEFS *ole, U16 max_level)
   verboseU32Array (root_list, len+1);
   /* read in root block depot */
   verbose ("read in root block depot (Root)");
-  o.Root = (U8 *)malloc (0x0200 * len);
+  o.Root = (uint8_t *)malloc (0x0200 * len);
   test_exitf (o.Root != NULL, 10, ends(&o));
   s = o.Root;
   for (i = 0; i < len; i++)
@@ -355,7 +360,7 @@ int cpp_OLEdecode (char *OLEfilename, COLEFS *ole, U16 max_level)
   verbose ("read pps entry details");
   for (i = 0; i < o.num_of_pps; i++)
     {
-      U16 size_of_name;
+      uint16_t size_of_name;
 
       s = o.Root + (i * 0x80);
 
@@ -363,11 +368,11 @@ int cpp_OLEdecode (char *OLEfilename, COLEFS *ole, U16 max_level)
       o.pps_list[i].ppsnumber = i;
 
       /* read the name */
-      size_of_name = (U16)MIN (0x40, fil_sreadU16 (s + 0x40));
+      size_of_name = (uint16_t)MIN (0x40, fil_sreadU16 (s + 0x40));
       o.pps_list[i].name[0] = 0;
       if (size_of_name == 0)
 	continue;
-      for (p = (U8 *) o.pps_list[i].name, t = s;
+      for (p = (uint8_t *) o.pps_list[i].name, t = s;
 	   t < s + size_of_name; t++)
 	*p++ = *t++;
       /* makes visible the non printable first character */
@@ -397,7 +402,7 @@ int cpp_OLEdecode (char *OLEfilename, COLEFS *ole, U16 max_level)
   /* NEXT IS VERBOSE verbose */
 #ifdef VERBOSE
   {
-    U32 i;
+    uint32_t i;
     printf ("before reorder pps tree\n");
     printf ("pps    type    prev     next      dir start   level size     name\n");
     for (i = 0; i < num_of_pps; i++)
@@ -429,7 +434,7 @@ int cpp_OLEdecode (char *OLEfilename, COLEFS *ole, U16 max_level)
   /* NEXT IS VERBOSE verbose */
 #ifdef VERBOSE
   {
-    U32 i;
+    uint32_t i;
     printf ("after reorder pps tree\n");
     printf ("pps    type    prev     next      dir start   level size     name\n");
     for (i = 0; i < num_of_pps; i++)
@@ -462,11 +467,11 @@ int cpp_OLEdecode (char *OLEfilename, COLEFS *ole, U16 max_level)
      wich is made with pps_list entries, is reordered */
   verbose ("create pps files");
   {
-    U8 *Depot;
+    uint8_t *Depot;
     FILE *OLEfile, *infile;
-    U16 BlockSize, Offset;
+    uint16_t BlockSize, Offset;
     size_t bytes_to_read;
-    U32 pps_size, pps_start;
+    uint32_t pps_size, pps_start;
 
     assert (o.num_of_pps >= 1);
     /* i < 1 --- before i < num_of_pps --- changed so not to generate the
@@ -570,14 +575,14 @@ int cpp_OLEdecode (char *OLEfilename, COLEFS *ole, U16 max_level)
 #endif
 	    FilePos = (pps_start + Offset) * BlockSize;
 	    assert (FilePos >= 0);
-	    bytes_to_read = MIN ((U32)BlockSize, pps_size);
+	    bytes_to_read = MIN ((uint32_t)BlockSize, pps_size);
 	    fseek (infile, FilePos, SEEK_SET);
 	    fread (o.Block, bytes_to_read, 1, infile);
 	    test_exitf (!ferror (infile), 5, ends(&o));		// TODO: Resource leak OleFile.
 	    fwrite (o.Block, bytes_to_read, 1, OLEfile);
 	    test_exitf (!ferror (infile), 5, ends(&o));
 	    pps_start = fil_sreadU32 (Depot + (pps_start * 4));
-	    pps_size -= MIN ((U32)BlockSize, pps_size);
+	    pps_size -= MIN ((uint32_t)BlockSize, pps_size);
 	    if (pps_size == 0)
 	      pps_start = 0xfffffffeUL;
 	  }
@@ -609,14 +614,14 @@ static int cole_extract_file (COLEFILE *OleFile)
 {
 	/* FIXME rewrite this cleanner */
 FILE *ret;
-U16 BlockSize, Offset;
-U8 *Depot;
+uint16_t BlockSize, Offset;
+uint8_t *Depot;
 FILE *infile;
 long FilePos;
 size_t bytes_to_copy;
-U8 Block[0x0200];
-U32 size;
-U32 pps_start;
+uint8_t Block[0x0200];
+uint32_t size;
+uint32_t pps_start;
 
   size=OleFile->fs->tree[OleFile->entry].size;
   pps_start=OleFile->fs->tree[OleFile->entry].start;
@@ -661,7 +666,7 @@ U32 pps_start;
 			free (OleFile->filename);
 			return 4;
 		}
-		bytes_to_copy = MIN ((U32)BlockSize, size);
+		bytes_to_copy = MIN ((uint32_t)BlockSize, size);
 		if (fseek (infile, FilePos, SEEK_SET)) {
 			fclose (ret);
 			remove (OleFile->filename);
@@ -683,7 +688,7 @@ U32 pps_start;
 			return 6;
 		}
 		pps_start = fil_sreadU32 (Depot + (pps_start * 4));
-		size -= MIN ((U32)BlockSize, size);
+		size -= MIN ((uint32_t)BlockSize, size);
 		if (size == 0)
 			break;
 	}
