@@ -24,6 +24,12 @@
  #define DIR_DEPARATOR '/'
 #endif
 
+#if defined(__MINGW32__) || defined(__MINGW64__)
+ #define LOCK_FILE_RIGHTS	"wb"
+#else
+ #define LOCK_FILE_RIGHTS	"wbx"
+#endif
+
 
 const char *Directory = NULL;
 
@@ -526,6 +532,7 @@ codepage symbol, Wingdings;
 //Translator trn;
 doublelist llHTML;
 string FileName;
+int TimeoutCounter;
 
  puts("<<<cplib>>> (c)1999-2023 J.Fojtik");
 
@@ -554,10 +561,17 @@ string FileName;
    printf("Lock \"%s\" found, waiting for cleanup from concurrent app.\n", FileLock());
    Sleep(500);
  }
- while((Flock=fopen(FileLock(),"wbx")) == NULL)
+ TimeoutCounter = 0;
+ while((Flock=fopen(FileLock(),LOCK_FILE_RIGHTS)) == NULL)
  {
-   printf("Lock \"%s\" found, waiting for cleanup from concurrent app.\n", FileLock());
-   Sleep(500);
+   printf("Lock \"%s\" cannot create lockfile, waiting for cleanup from concurrent app.\n", FileLock());
+   Sleep(400);
+   TimeoutCounter += 400;
+   if(TimeoutCounter > 12000)
+   {
+     printf("Fatal: Cannot obtain Lock \"%s\" for %d[ms], bailing out.\n", FileLock(), TimeoutCounter);
+     exit(EXIT_FAILURE);
+   }
  }
  fprintf(Flock,"running");
 #endif
@@ -566,8 +580,8 @@ string FileName;
 
  //printf("%ld\n",coreleft());
 
- doublelist WP2LaTeX(ReadCodeGenerator("chars.c_"));
- //WP2LaTeX.doublelist::operator=(WP2LaTeX,ReadCodeGenerator("chars.c_"));
+ doublelist WP2LaTeX(ReadCodeGenerator("chars.inf"));
+ //WP2LaTeX.doublelist::operator=(WP2LaTeX,ReadCodeGenerator("chars.inf"));
 
  WP2LaTeX.Flip(0);
  ForgeFname(FileName, "internal.enc");
