@@ -12,11 +12,11 @@ public: codepage(void)	{name=NULL;characters=NULL;MaxUsed=Allocated=0;};
 	~codepage(void);
 
 	char *name;
-	WORD Allocated;
-	WORD MaxUsed;
+	uint16_t Allocated;
+	uint16_t MaxUsed;
 	char **characters;
 
-	void InsertCharDesc(WORD position, const char *Name);
+	void InsertCharDesc(uint16_t position, const char *Name);
         void Erase(void);
 	};
 
@@ -28,7 +28,7 @@ public: Translator(void)  {ToCp=FromCp=NULL;Data=NULL;}
 
 	const codepage *FromCp;
 	const codepage *ToCp;
-	WORD *Data;
+	uint16_t *Data;
 
 	void erase(void);
 	};
