@@ -489,7 +489,7 @@ NewTest:
 	    ( (isalpha(c)) && (isalpha(*symbol)) ) ||
 	    ( (isdigit(c)) && (isdigit(*symbol)) ) )
 		  {
-		  str=strstr(++str, symbol);
+		  str = strstr(++str, symbol);
 		  goto NewTest;
 		  }
 	 }
@@ -621,7 +621,7 @@ bool FirstCipher = false;
      {
      c = str[0];
 
-     if (i <= 0 && LastC!='\\' && length(arg)>0)
+     if(i <= 0 && LastC!='\\' && length(arg)>0)
 	{
 	if (c == '^' || c == '_' || c == '{' || c == '\\' || c == '&' || c == '#' || c == ',' || c == ';' ||
 	    c == '$' || c == '@' || c == '%' || c == '*'  || isspace(c) || c == '+' || c == '-' || c == '=' ||
@@ -729,7 +729,7 @@ bool FirstCipher = false;
   {
   if(arg==FmlTransTable[i].szWP || InternalArg==FmlTransTable[i].szWP)
     {
-    if(strstr(FmlTransTable[i].szTeX,"1")!=NULL)
+    if(strchr(FmlTransTable[i].szTeX,'1')!=NULL)
 	{
 	if(LastC=='}')	//the curly brace was removed - add it
 	   {
@@ -741,7 +741,7 @@ bool FirstCipher = false;
 	   arg=arg+'{'+InternalArg+'}';
 	else
 	   arg+=' '+InternalArg;
-	if(strstr(FmlTransTable[i].szTeX,"2")!=NULL)
+	if(strchr(FmlTransTable[i].szTeX,'2')!=NULL)
 	   {
 	   if(Remove1stArg(str,InternalArg)=='}')
 	     arg=arg+'{'+InternalArg+'}';
@@ -757,7 +757,6 @@ return(LastC);
 }
 
 
-
 /** This procedure removes argument from the beginning of the string with x^y_z stuff.
  * @param[in,out] str	Formula data that shoud be split.
  * @param[out]	  arg	Argument extracred from formula. */
@@ -777,21 +776,21 @@ string InternalArg;
   ZeroPass = Level = 0;
   while(!str.isEmpty())
      {
-     c = str[0];     
+     c = str[0];
      if(Level<=0 && !isspace(c))
        {
-       if(c==BlockChar) break;
+       if(c==BlockChar || c=='#') break;
        if(!LastSupSub && !arg.isEmpty())	//argument is not empty
 	 {
 	 if((isspace(LastC) ||
 	      LastC=='}' || LastC==']' || LastC==')' || LastC=='"' || LastC=='\'') &&
 	    (!isspace(c) && c!='_' && c!='^') ) break;
 
-	 if(c=='\\' ||                    //These characters break WP argument
+	 if(c=='\\' ||				//These characters break WP argument
 	   c==',' || c=='?' || c=='!' ||
 	   c=='(' || c==')' || c=='[' || c==']' ||
 	   c=='*' || c == '/' || c=='+' || c == '-' ||
-	   c=='@' || c=='$'  || c=='=' || c=='~') 
+	   c=='@' || c=='$'  || c=='=' || c=='~' || c=='&')
              {
              if(LastC == '\\')
                {
@@ -858,13 +857,13 @@ for(int j=0; j<nFmlTransWords; j++)
   {
   if(arg==FmlTransTable[j].szWP || InternalArg==FmlTransTable[j].szWP)
     {
-    if(strstr(FmlTransTable[j].szTeX,"1")!=NULL)
+    if(strchr(FmlTransTable[j].szTeX,'1')!=NULL)
 	{
 	if(Remove1stArg(str,InternalArg)=='}')
 	   arg = arg+"{"+InternalArg+"}";
 	else
 	   arg+=" "+InternalArg;
-	if(strstr(FmlTransTable[j].szTeX,"2")!=NULL)
+	if(strchr(FmlTransTable[j].szTeX,'2')!=NULL)
 	   {
 	   if(Remove1stArg(str,InternalArg)=='}')
 	     arg = arg + "{"+InternalArg + "}";
@@ -1499,7 +1498,7 @@ uint8_t styles;
   if(StrBeg.isEmpty()) return(false);  /*equation is empty-nothing to do*/
 
   StrBeg = replacesubstring(StrBeg,"\1}","\\}");	// fix \} in WP -> \1 -> "\}"
-  StrBeg = replacesubstring(StrBeg,"\1{","\\{");	// fix \} in WP -> \1 -> "\}"  
+  StrBeg = replacesubstring(StrBeg,"\1{","\\{");	// fix \} in WP -> \1 -> "\}"
   bool error = FixFormula(cq,StrBeg,i,j);
 
 	//Here starts an equation conversion phase
@@ -1582,16 +1581,16 @@ uint8_t styles;
            arg[1].erase();
 	   arg[2].erase();
 
-	   if(strstr(FmlTransTable[i].szTeX, "8") != NULL)
+	   if(strchr(FmlTransTable[i].szTeX, '8') != NULL)
 	       {
 	       RemoveAdvancedLastArg(StrBeg, arg[0]);
 	       }
-	   if(strstr(FmlTransTable[i].szTeX, "0") != NULL)
+	   if(strchr(FmlTransTable[i].szTeX, '0') != NULL)
 	       {
 	       RemoveLastArg(StrBeg,arg[0]);
 	       }
 
-	   if(strstr(FmlTransTable[i].szTeX, "9") != NULL)
+	   if(strchr(FmlTransTable[i].szTeX, '9') != NULL)
 	       {
 	       if(FmlTransTable[i].szWP[0]=='_') 
 			RemoveAdvanced1stArg(StrEnd, arg[1], '^');	// Stop on oposite accent
@@ -1599,12 +1598,12 @@ uint8_t styles;
 			RemoveAdvanced1stArg(StrEnd, arg[1], '_');	// Stop on oposite accent
 	       else RemoveAdvanced1stArg(StrEnd, arg[1]);		// Grab both subscript and also superscript.
 	       } 
-           else if(strstr(FmlTransTable[i].szTeX, "1") != NULL)
+           else if(strchr(FmlTransTable[i].szTeX, '1') != NULL)
 	       {
 	       Remove1stArg(StrEnd,arg[1]);
 	       }
 
-	   if(strstr(FmlTransTable[i].szTeX, "2") != NULL)
+	   if(strchr(FmlTransTable[i].szTeX, '2') != NULL)
 	       {
 	       Remove1stArg(StrEnd,arg[2]);
 	       }
@@ -1618,7 +1617,7 @@ uint8_t styles;
 	   }
       }
 
-  StrEnd = StrBeg + StrEnd; /* Fix double superscript/subscript */  
+  StrEnd = StrBeg + StrEnd; /* Fix double superscript/subscript */
   StrBeg.erase();
 
   //if(cq->log!=NULL) fprintf(cq->log,"\n%s\n",chk(StrEnd())); ///<<<<<
@@ -1655,7 +1654,7 @@ uint8_t styles;
         i--;
       }
     }
-    
+
     while(i>0)
       {
       i--;
