@@ -64,7 +64,7 @@ return(temp);
 }
 
 
-void Proces_File(const string filename)
+void Proces_File(const string &filename)
 {
 //#ifdef DEBUG
 //  fprintf(cq->log,"\n!Proces_File(%s) ",filename.ch);fflush(cq->log);
