@@ -14,10 +14,11 @@
 
 class TconvertedPass1;
 class AbstractTransformXY;
-float *LoadPoints(TconvertedPass1 *cq, int n, FloatBBox &bbx, AbstractTransformXY *TRx=NULL,bool Precision=false,float LineWidth=0);
+float *LoadPoints(TconvertedPass1 *cq, int n, bool Precision=false, float *Points=NULL);
+void FixBoundingBox(float *Points, int n, FloatBBox &bbx, AbstractTransformXY *TRx=NULL, float LineWidth=0);
 
 
-void AddCharacterToContainer(TextContainer *pTextCont, WORD WchI, const CpTranslator *PsNativeCP, const CpTranslator *PsNativeSym, 
+void AddCharacterToContainer(TextContainer *pTextCont, uint16_t WchI, const CpTranslator *PsNativeCP, const CpTranslator *PsNativeSym, 
 		TconvertedPass1 *cq, PS_State &PSS);
 
 #endif // __IMAGES_H__
\ No newline at end of file
