@@ -91,6 +91,25 @@ char c;
 }
 
 
+/** Flip R and B and invert A coupounds in place.
+ * param[in]	Data	Pointer to data.
+ * param[in]	Size	Amount of RGB tripplets. */
+void RGBA64_BGRiA64(char *Data, int PixelCount)
+{
+uint16_t c;
+uint16_t *Data16 = (uint16_t *)Data;
+
+  while(PixelCount-->0)
+  {
+    c = Data16[2];
+    Data16[2] = *Data16;
+    *Data16 = c;
+    Data16[3] = ~Data16[3];
+    Data16 += 4;
+  }
+}
+
+
 /** Flip R and B coupounds to the different buffer. */
 void RGB_BGR2(unsigned char *OutData, const unsigned char *InData, unsigned PixelCount)
 {
@@ -155,7 +174,7 @@ void NotR(char *R, int size)	//R1:=not(R1)
   while(size>=4)
   {
     *(uint32_t*)R = ~ *(uint32_t*)R;
-    R += sizeof(uint32_t*);
+    R += sizeof(uint32_t);
     size -= 4;
   }
   while(size-->0)
