@@ -257,17 +257,32 @@ TImageFileHandler HANDLER_##SUFFIX(EXTENSION,
 	NULL);
  #endif
 
- TImageFileHandler PPM_H(".PPM",
+int SavePicturePGM(const char *Name,const Image &Img);
+TImageFileHandler HANDLER_PGM(".PGM",
  #if SupportPBM>=4 || SupportPBM==2
 	LoadPicturePBM,
  #else
 	NULL,
  #endif
  #if SupportPBM>=3
-	SavePicturePBM);
+	SavePicturePGM);
  #else
 	NULL);
  #endif
+
+int SavePicturePPM(const char *Name,const Image &Img);
+TImageFileHandler HANDLER_PPM(".PPM",
+ #if SupportPBM>=4 || SupportPBM==2
+	LoadPicturePBM,
+ #else
+	NULL,
+ #endif
+ #if SupportPBM>=3
+	SavePicturePPM);
+ #else
+	NULL);
+ #endif
+
 #endif
 
 
