@@ -242,7 +242,7 @@ uint16_t *Prefix=NULL,*Suffix=NULL;
 uint16_t Nacteno;
 FILE *f;
 Image Img,*CurrImg;
-uint16_t InCode,OldCode,CurCode,Code,ClearCode,OutCount,FirstFree,FreeCode,EOFCode,MaxCode;
+uint16_t InCode,OldCode,Code,ClearCode,OutCount,FirstFree,FreeCode,EOFCode,MaxCode;
 uint8_t FinChar,BitMask,CodeSize,InitCodeSize;
 uint16_t X,Y;
 int Interlace;
@@ -368,14 +368,14 @@ int I;
 		   Code = bit.Read_N(CodeSize);
 	           //fprintf(F,"%u(%u) X=%u; Y=%u\n", Code, CodeSize, X, Y);
 
-		   CurCode = Code;
+		   //CurCode = Code;
 		   OldCode = Code;
 		   FinChar = Code & BitMask;
 		   Add2Pixel (Raster,FinChar,X,Y,Interlace);
 		   }
 	       else
 		   {
-		   CurCode = Code;
+		   uint16_t CurCode = Code;
 		   InCode = Code;
 		   if(Code >= FreeCode)
 			{
