@@ -9,6 +9,7 @@
 #include <string.h>
 
 #include "imgsupp.h"
+#include "image.h"
 
 
 #define MaxTextExtent 256
@@ -517,7 +518,7 @@ int row_stride;		 /* physical row width in image buffer */
       {
       case ImagePalette:{                               //palette image
              RGBQuad RGB;
-             BYTE *ptrLine=(BYTE *)ptrLineX;
+             uint8_t *ptrLine=(uint8_t *)ptrLineX;
              for(unsigned X=0;X<RasLine->GetSize1D();X++)
 	       {
 	       Img.Palette->Get(RasLine->GetValue1D(X),&RGB);
