@@ -100,25 +100,36 @@ int i;
 	/* read file */
     if(setjmp(png_jmpbuf(png_ptr))) goto FINISH;	  // [read_png_file] Error during read_image
 
+    //printf("\nPNG: channels: %d", png_get_channels(png_ptr,info_ptr));
     switch(png_get_channels(png_ptr,info_ptr))
     {
-      case 1: if(png_get_rowbytes(png_ptr,info_ptr) > (png_get_image_width(png_ptr,info_ptr)*png_get_bit_depth(png_ptr,info_ptr)+7)/8) goto FINISH;
-	    Raster = CreateRaster2D(png_get_image_width(png_ptr,info_ptr),png_get_image_height(png_ptr,info_ptr),png_get_bit_depth(png_ptr,info_ptr));
+      case 1:
+            //printf("\nPNG: png_get_bit_depth: %d", png_get_bit_depth(png_ptr,info_ptr));
+            //printf("\nPNG: png_get_rowbytes():%d %u", png_get_rowbytes(png_ptr,info_ptr), (png_get_image_width(png_ptr,info_ptr)*png_get_bit_depth(png_ptr,info_ptr)+7)/8);
+            if(png_get_rowbytes(png_ptr,info_ptr) > (png_get_image_width(png_ptr,info_ptr)*png_get_bit_depth(png_ptr,info_ptr)+7)/8) goto FINISH;
+	    Raster = CreateRaster2D(png_get_image_width(png_ptr,info_ptr),png_get_image_height(png_ptr,info_ptr),
+		                    NearAvailPlanes(png_get_bit_depth(png_ptr,info_ptr)));
 
-            png_get_PLTE(png_ptr,info_ptr, &palette, &num_palette);
-            if(num_palette>0 && palette!=NULL)
+            palette = NULL;		// Prevent uninitialised value.
+            if(PNG_INFO_PLTE==png_get_PLTE(png_ptr,info_ptr, &palette, &num_palette))
+            {
+              //printf("\nPNG: num_palette: %d", num_palette);
+              if(num_palette>0 && palette!=NULL)
               {
-              Palette = BuildPalette(num_palette,8);
-	      if(Palette)
+                if(Raster!=NULL && num_palette>(1<<Raster->GetPlanes()))
+                    num_palette = 1<<Raster->GetPlanes();		// Shrink oversized palette.
+                Palette = BuildPalette(num_palette,8);
+	        if(Palette)
                 {
-                for(i=0;i<num_palette;i++)
+                  for(i=0;i<num_palette;i++)
 		  {
-		  Palette->setR(i,palette[i].red);
-		  Palette->setG(i,palette[i].green);
-		  Palette->setB(i,palette[i].blue);
+		    Palette->setR(i,palette[i].red);
+		    Palette->setG(i,palette[i].green);
+		    Palette->setB(i,palette[i].blue);
                   }
-		}
+                }
               }
+            }
 	    break;
       case 3: if(png_get_rowbytes(png_ptr,info_ptr) > (3*png_get_image_width(png_ptr,info_ptr)*png_get_bit_depth(png_ptr,info_ptr))/8) goto FINISH;
 	    Raster = CreateRaster2DRGB(png_get_image_width(png_ptr,info_ptr),png_get_image_height(png_ptr,info_ptr),png_get_bit_depth(png_ptr,info_ptr));
@@ -171,8 +182,6 @@ FINISH:
 
 int SavePicturePNG(const char *Name, const Image &Img)
 {
-png_colorp palette = NULL;
-
   if(Img.Raster==NULL) return(-10);
 
 	/* create file */
@@ -257,24 +266,32 @@ png_colorp palette = NULL;
               png_set_sBIT(png_ptr, info_ptr, &sig_bit);
               break;
     case ImagePalette:
-              png_set_IHDR(png_ptr, info_ptr, Img.Raster->Size1D, Img.Raster->Size2D,
+              {
+                //printf("\npng_set_IHDR: %d", Img.Raster->GetPlanes());
+                png_set_IHDR(png_ptr, info_ptr, Img.Raster->Size1D, Img.Raster->Size2D,
 		     Img.Raster->GetPlanes(), PNG_COLOR_TYPE_PALETTE, PNG_INTERLACE_NONE,
 		     PNG_COMPRESSION_TYPE_BASE, PNG_FILTER_TYPE_BASE);
 		   /* Set the palette if there is one.  REQUIRED for indexed-color images */
-	      palette = (png_colorp)png_malloc(png_ptr, PNG_MAX_PALETTE_LENGTH*png_sizeof(png_color));
-		   /* ... Set palette colors ... */
-              for(int i=0; i<PNG_MAX_PALETTE_LENGTH; i++)
-	      {
-		  palette[i].red = Img.Palette->R(i);
-		  palette[i].green = Img.Palette->G(i);
-		  palette[i].blue = Img.Palette->B(i);
-              }
-	      png_set_PLTE(png_ptr, info_ptr, palette, PNG_MAX_PALETTE_LENGTH);
+                int num_palette = 1 << Img.Raster->GetPlanes();
+		if(num_palette>PNG_MAX_PALETTE_LENGTH) num_palette=PNG_MAX_PALETTE_LENGTH;
+                //printf("\npng_malloc: %ld", (long)num_palette*png_sizeof(png_color));
+	        png_colorp palette = (png_colorp)png_malloc(png_ptr, num_palette*png_sizeof(png_color));
+		if(palette != NULL)
+		{	   /* ... Set palette colors ... */
+                  for(int i=0; i<num_palette; i++)
+	          {
+		    palette[i].red = Img.Palette->R(i);
+		    palette[i].green = Img.Palette->G(i);
+		    palette[i].blue = Img.Palette->B(i);
+                  }
+                  //printf("\npng_set_PLTE: %d", num_palette);
+	          png_set_PLTE(png_ptr, info_ptr, palette, num_palette);
 		  /* You must not free palette here, because png_set_PLTE only makes a link to
 		   * the palette that you malloced.  Wait until you are about to destroy
 		   * the png structure.  */		  
+		}
+              }
               break;
-
     default:  fclose(fp);
               png_destroy_write_struct(&png_ptr, &info_ptr);
               return -5;
