@@ -37,7 +37,7 @@ int NearAvailPlanes(int n)
   {
     if(n==0) return 0;
     if(n>=-32) return -32;	// float
-    return -64;			// double    
+    return -64;			// double
   }
   if(n<=1) return(1);		// bit
   if(n<=2) return(2);
@@ -143,7 +143,7 @@ int shift;
 /** Copy data from a given container. */
 void Raster1DAbstract::Set(const Raster1DAbstract &R1)
 {
-unsigned i,maxi;
+unsigned i, maxi;
 signed char shift;
 
   if(Data1D==NULL || R1.Data1D==NULL) return;
@@ -157,7 +157,24 @@ signed char shift;
     return;
   }
 
-  if(GetPlanes()<0 || R1.GetPlanes()<0)		// Floating point operation
+	// RGB to gray conversion.
+  if(Channels()==1 && Channels()!= R1.Channels())
+  {
+    RGBQuad RGB;
+    shift = R1.GetPlanes()/R1.Channels() - GetPlanes();
+    if(shift>=0)
+    {
+      int k = 3* ((1<<shift)-1);
+      for(i=0; i<maxi; i++)
+      {
+        R1.Get(i,&RGB);
+        SetValue1D(i, (RGB.R+RGB.G+RGB.B)/k);
+      }
+      return;
+    }
+  }
+
+  if(GetPlanes()<0 || R1.GetPlanes()<0)		// Floating point operations
   {
     for(i=0;i<maxi;i++)
       SetValue1Dd(i,R1.GetValue1Dd(i));
@@ -1060,7 +1077,7 @@ unsigned i;
 uint8_t *b=(uint8_t *)Data1D;
 
   if((plane8 & 0x3)!=0 || plane8>16)
-    {Raster1DAbstract::Peel8Bit(Buffer8Bit,plane8); return;}
+    {((Raster1DAbstract*)this)->Peel8Bit(Buffer8Bit,plane8); return;}
 
   b += plane8 >> 3;
   for(i=0;i<Size1D;i++)
@@ -1082,7 +1099,7 @@ unsigned i;
 uint8_t *b=(uint8_t *)Data1D;
 
   if((plane8 & 0x3)!=0 || plane8>16)
-    {Raster1DAbstract::Join8Bit(Buffer8Bit,plane8); return;}
+    {((Raster1DAbstract*)this)->Join8Bit(Buffer8Bit,plane8); return;}
 
   b += plane8 >> 3;
   for(i=0;i<Size1D;i++)
@@ -1904,17 +1921,17 @@ void Raster1D_16BitA1R5G5B5:Get24BitRGB(void *Buffer24Bit) const
 
 unsigned Raster1D_16Bit565::R(unsigned x) const
 {
-  return((((uint16_t*)Data1D)[x]>>8)&0xF8);
+  return((((const uint16_t*)Data1D)[x]>>8)&0xF8);
 }
 
 unsigned Raster1D_16Bit565::G(unsigned x) const 
 {
-  return((((uint16_t*)Data1D)[x]>>3)&0xFC);
+  return((((const uint16_t*)Data1D)[x]>>3)&0xFC);
 }
 
 unsigned Raster1D_16Bit565::B(unsigned x) const 
 {
-  return((((uint16_t*)Data1D)[x]&0x1F)<<3);
+  return((((const uint16_t*)Data1D)[x]&0x1F)<<3);
 }
 
 /* 8 bit planes for 3 channels R,G,B */
@@ -1923,9 +1940,9 @@ uint32_t Raster1D_8BitRGB::GetValue1D(unsigned x) const
 {
   if(x>=Size1D) return 0;
   x *= 3;
-  return((uint32_t)(((uint8_t *)Data1D)[x]) |
-	   ((uint32_t)(((uint8_t *)Data1D)[x+1])<<8) |
-	   ((uint32_t)(((uint8_t *)Data1D)[x+2])<<16));
+  return((uint32_t)(((const uint8_t *)Data1D)[x]) |
+	   ((uint32_t)(((const uint8_t *)Data1D)[x+1])<<8) |
+	   ((uint32_t)(((const uint8_t *)Data1D)[x+2])<<16));
 }
 
 void Raster1D_8BitRGB::SetValue1D(unsigned x, uint32_t NewValue)
@@ -1954,6 +1971,7 @@ uint8_t *ptrb;
  RGB->R = *ptrb++;
  RGB->G = *ptrb++;
  RGB->B = *ptrb;
+ RGB->O = 0;
 }
 
 
@@ -1987,13 +2005,13 @@ uint32_t Raster1D_16BitRGB::GetValue1D(unsigned x) const
   if(x>=Size1D) return 0;
   x *= 6;
 #ifdef HI_ENDIAN
-  return((uint32_t)((uint8_t *)Data1D)[x+0] |
-        ((uint32_t)((uint8_t *)Data1D)[x+2])<<8 |
-        ((uint32_t)((uint8_t *)Data1D)[x+4])<<16);
+  return((uint32_t)((const uint8_t *)Data1D)[x+0] |
+        ((uint32_t)((const uint8_t *)Data1D)[x+2])<<8 |
+        ((uint32_t)((const uint8_t *)Data1D)[x+4])<<16);
 #else
-   return((uint32_t)((uint8_t *)Data1D)[x+1] |
-        ((uint32_t)((uint8_t *)Data1D)[x+3])<<8 |
-        ((uint32_t)((uint8_t *)Data1D)[x+5])<<16);
+   return((uint32_t)((const uint8_t *)Data1D)[x+1] |
+        ((uint32_t)((const uint8_t *)Data1D)[x+3])<<8 |
+        ((uint32_t)((const uint8_t *)Data1D)[x+5])<<16);
 #endif
 }
 
@@ -2017,10 +2035,10 @@ void Raster1D_16BitRGB::Get24BitRGB(void *Buffer24Bit) const
 
 void Raster1D_16BitRGB::Get(unsigned index, RGBQuad *RGB) const
 {
-uint16_t *ptrw;
+const uint16_t *ptrw;
 
  if(RGB==NULL || Data1D==NULL || Size1D<index) return;
- ptrw = (uint16_t*)(((uint8_t *)Data1D)+6*index);
+ ptrw = (const uint16_t*)(((const uint8_t *)Data1D)+6*index);
  RGB->R = *ptrw++;
  RGB->G = *ptrw++;
  RGB->B = *ptrw++;
@@ -2034,13 +2052,13 @@ uint32_t Raster1D_16BitRGB::PTR_GetValue1D(const void *RAW_Data1D, unsigned x) c
   if(x>=Size1D) return 0;
   x *= 6;
 #ifdef HI_ENDIAN
-  return((uint32_t)((uint8_t *)RAW_Data1D)[x+0] |
-        ((uint32_t)((uint8_t *)RAW_Data1D)[x+2])<<8 |
-        ((uint32_t)((uint8_t *)RAW_Data1D)[x+4])<<16);
+  return((uint32_t)((const uint8_t *)RAW_Data1D)[x+0] |
+        ((uint32_t)((const uint8_t *)RAW_Data1D)[x+2])<<8 |
+        ((uint32_t)((const uint8_t *)RAW_Data1D)[x+4])<<16);
 #else
-  return((uint32_t)((uint8_t *)RAW_Data1D)[x+1] |
-        ((uint32_t)((uint8_t *)RAW_Data1D)[x+3])<<8 |
-        ((uint32_t)((uint8_t *)RAW_Data1D)[x+5])<<16);
+  return((uint32_t)((const uint8_t *)RAW_Data1D)[x+1] |
+        ((uint32_t)((const uint8_t *)RAW_Data1D)[x+3])<<8 |
+        ((uint32_t)((const uint8_t *)RAW_Data1D)[x+5])<<16);
 #endif
 }
 
@@ -2100,7 +2118,7 @@ uint8_t *BBuffer24Bit = (uint8_t *)Buffer24Bit;
   if(Buffer24Bit==NULL) return;
   for(unsigned x=0; x<Size1D; x++)
   {
-    const uint32_t d = ((uint32_t *)Data1D)[x];
+    const uint32_t d = ((const uint32_t *)Data1D)[x];
     *BBuffer24Bit++ = d & 0xFF;
     *BBuffer24Bit++ = (d>>8) & 0xFF;
     *BBuffer24Bit++ = (d>>16) & 0xFF;
@@ -2109,6 +2127,13 @@ uint8_t *BBuffer24Bit = (uint8_t *)Buffer24Bit;
 
 
 #ifdef _REENTRANT
+
+uint32_t Raster1D_8BitRGBA::PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const
+{
+  if(x>=Size1D) return 0;
+  return ((const uint32_t*)RAW_Data1D)[x];
+}
+
 void Raster1D_8BitRGBA::PTR_SetValue1D(void *RAW_Data1D, unsigned x, uint32_t NewValue) const
 {
   if(Size1D<=x) return;
@@ -2130,15 +2155,15 @@ uint32_t Raster1D_16BitRGBA::GetValue1D(unsigned x) const
   if(x>=Size1D) return 0;
   x *= 8;
 #ifdef HI_ENDIAN
-  return((uint32_t)((uint8_t *)Data1D)[x+0] |
-	((uint32_t)((uint8_t *)Data1D)[x+2])<<8 |
-	((uint32_t)((uint8_t *)Data1D)[x+4])<<16 |
-	((uint32_t)((uint8_t *)Data1D)[x+6])<<24);
+  return((uint32_t)((const uint8_t *)Data1D)[x+0] |
+	((uint32_t)((const uint8_t *)Data1D)[x+2])<<8 |
+	((uint32_t)((const uint8_t *)Data1D)[x+4])<<16 |
+	((uint32_t)((const uint8_t *)Data1D)[x+6])<<24);
 #else
-  return((uint32_t)((uint8_t *)Data1D)[x+1] |
-	((uint32_t)((uint8_t *)Data1D)[x+3])<<8 |
-	((uint32_t)((uint8_t *)Data1D)[x+5])<<16 |
-	((uint32_t)((uint8_t *)Data1D)[x+7])<<24);
+  return((uint32_t)((const uint8_t *)Data1D)[x+1] |
+	((uint32_t)((const uint8_t *)Data1D)[x+3])<<8 |
+	((uint32_t)((const uint8_t *)Data1D)[x+5])<<16 |
+	((uint32_t)((const uint8_t *)Data1D)[x+7])<<24);
 #endif
 }
 
@@ -2158,6 +2183,15 @@ void Raster1D_16BitRGBA::SetValue1D(unsigned x, uint32_t NewValue)
 
 
 #ifdef _REENTRANT
+uint32_t Raster1D_16BitRGBA::PTR_GetValue1D(const void *RAW_Data1D, unsigned x) const
+{
+  if(x>=Size1D) return 0;
+  return((uint32_t)((const uint8_t *)RAW_Data1D)[x+1] |
+	((uint32_t)((const uint8_t *)RAW_Data1D)[x+3])<<8 |
+	((uint32_t)((const uint8_t *)RAW_Data1D)[x+5])<<16 |
+	((uint32_t)((const uint8_t *)RAW_Data1D)[x+7])<<24);
+}
+
 void Raster1D_16BitRGBA::PTR_SetValue1D(void *RAW_Data1D, unsigned x, uint32_t NewValue) const
 {
   if(Size1D<=x) return;
@@ -2349,7 +2383,7 @@ void Raster2DAbstract::Get(unsigned Offset2D, Raster1DAbstract &R1) MP_CONST
   Raster1DAbstract::PTR_Get(Data2D[Offset2D],R1);
 #else
   Data1D = Data2D[Offset2D];
-  Raster1DAbstract::Get(R1);
+  ((Raster1DAbstract*)this)->Get(R1);
 #endif
 }
 
@@ -2358,7 +2392,7 @@ void Raster2DAbstract::Get(unsigned Offset1D, unsigned Offset2D, RGBQuad *RGB)
 {
   if(Data2D==NULL || Offset2D>=Size2D) return;
   Data1D = Data2D[Offset2D];
-  Raster1DAbstract::Get(Offset1D,RGB);
+  ((const Raster1DAbstract*)this)->Get(Offset1D,RGB);		//Raster1DAbstract::Get() forces only one method not using VMT.
 }
 
 
@@ -2369,7 +2403,7 @@ void Raster2DAbstract::Set(unsigned Offset2D, const Raster1DAbstract &R1)
   Raster1DAbstract::PTR_Set(Data2D[Offset2D],R1);
 #else
   Data1D = Data2D[Offset2D];
-  Raster1DAbstract::Set(R1);
+  ((Raster1DAbstract*)this)->Set(R1);
 #endif
 }
 
