@@ -151,7 +151,7 @@ public: mutable short UsageCount;
 	virtual double GetValue1Dd(unsigned x) const {return(GetValue1D(x));};
 	virtual void SetValue1D(unsigned x, uint32_t NewValue) ABSTRACT_ERROR("SetValue1D");
 	virtual void SetValue1Dd(unsigned x, double NewValue) {SetValue1D(x,(uint32_t)NewValue);};
-	virtual void Get(unsigned x, RGBQuad *RGB) const {RGB->R=RGB->G=RGB->B=GetValue1D(x);};
+	virtual void Get(unsigned x, RGBQuad *RGB) const {RGB->O=0;RGB->R=RGB->G=RGB->B=GetValue1D(x);};
 
 	virtual int GetPlanes(void) const {return(0);};
 	virtual unsigned GetSize1D(void) const {return(Size1D);};
@@ -200,8 +200,8 @@ public:
   virtual void Set(const Raster1DAbstract &R1);
   virtual void Set(const Raster1DAbstract &R1, const Raster1DAbstract &Palette);
 
-  virtual void Get(unsigned index, RGBQuad *RGB) const;
-  virtual void Set(unsigned index, const RGBQuad *RGB);
+  virtual void Get(unsigned x, RGBQuad *RGB) const;
+  virtual void Set(unsigned x, const RGBQuad *RGB);
 
   uint32_t R(unsigned x) const {return(GetValue1DRAW(3*x));}
   uint32_t G(unsigned x) const {return(GetValue1DRAW(3*x+1));}
@@ -234,8 +234,8 @@ public:
 
   virtual void Set(const Raster1DAbstract &R1);
 
-  virtual void Get(unsigned index, RGBQuad *RGB) const;
-  virtual void Set(unsigned index, const RGBQuad *RGB);
+  virtual void Get(unsigned x, RGBQuad *RGB) const;
+  virtual void Set(unsigned x, const RGBQuad *RGB);
 
   uint32_t R(unsigned x) const {return(GetValue1DRAW(4*x));}
   uint32_t G(unsigned x) const {return(GetValue1DRAW(4*x+1));}
