@@ -1,5 +1,5 @@
 /*********************************************************
-* unit:    raster            release 0.23                *
+* unit:    raster            release 0.25                *
 * purpose: general manipulation n dimensional matrices   *
 *          n = 1, 2 and 3.			         *
 * licency:     GPL or LGPL                               *
@@ -19,9 +19,9 @@
 
 /*--------------1 bit---------------- */
 
-void Conv1_4(BYTE *Dest, const BYTE *Src, unsigned Size1D)
+void Conv1_4(uint8_t *Dest, const uint8_t *Src, unsigned Size1D)
 {
-BYTE Mask;
+uint8_t Mask;
 
   while(Size1D>0)
     {
@@ -48,9 +48,9 @@ BYTE Mask;
 }
 
 
-void Conv1_8(BYTE *Dest, const BYTE *Src, unsigned Size1D)
+void Conv1_8(uint8_t *Dest, const uint8_t *Src, unsigned Size1D)
 {
-BYTE Mask;
+uint8_t Mask;
 
   while(Size1D>0)
     {
@@ -66,9 +66,9 @@ BYTE Mask;
     }
 }
 
-void Conv1_16(WORD *Dest, const BYTE *Src, unsigned Size1D)
+void Conv1_16(uint16_t *Dest, const uint8_t *Src, unsigned Size1D)
 {
-BYTE Mask;
+uint8_t Mask;
 
   while(Size1D>0)
     {
@@ -84,10 +84,10 @@ BYTE Mask;
     }
 }
 
-void Conv1_24(BYTE *Dest, const BYTE *Src, unsigned Size1D)
+void Conv1_24(uint8_t *Dest, const uint8_t *Src, unsigned Size1D)
 {
-BYTE Mask;
-BYTE Value;
+uint8_t Mask;
+uint8_t Value;
 
   while(Size1D>0)
     {
@@ -106,9 +106,9 @@ BYTE Value;
     }
 }
 
-void Conv1_32(DWORD *Dest, const BYTE *Src, unsigned Size1D)
+void Conv1_32(uint32_t *Dest, const uint8_t *Src, unsigned Size1D)
 {
-BYTE Mask;
+uint8_t Mask;
 
   while(Size1D>0)
     {
@@ -125,10 +125,10 @@ BYTE Mask;
 }
 
 
-#ifdef QWORD
-void Conv1_64(QWORD *Dest, const BYTE *Src, unsigned Size1D)
+#if defined(uint64_t) || defined(uint64_t_defined)
+void Conv1_64(uint64_t *Dest, const uint8_t *Src, unsigned Size1D)
 {
-BYTE Mask;
+uint8_t Mask;
 
   while(Size1D>0)
     {
@@ -149,9 +149,9 @@ BYTE Mask;
 /*--------------4 bit---------------- */
 
 
-void Conv4_1(BYTE *Dest, const BYTE *Src, unsigned Size1D)
+void Conv4_1(uint8_t *Dest, const uint8_t *Src, unsigned Size1D)
 {
-BYTE Mask;
+uint8_t Mask;
 
   while(Size1D>0)
     {
@@ -169,14 +169,14 @@ BYTE Mask;
 }
 
 
-void Conv4_8(BYTE *Dest, const BYTE *Src, unsigned Size1D)
+void Conv4_8(uint8_t *Dest, const uint8_t *Src, unsigned Size1D)
 {
   while(Size1D>0)
     {
     *Dest = (*Src>>4) | (*Src&0xF0);  /* Duplicate nibble. */
     Dest++;
     if(Size1D-- <= 1) break;
-    *Dest = (WORD)(*Src & 0xF) | (*Src<<4);
+    *Dest = (uint16_t)(*Src & 0xF) | (*Src<<4);
     Dest++;
     Src++;
     Size1D--;
@@ -184,9 +184,9 @@ void Conv4_8(BYTE *Dest, const BYTE *Src, unsigned Size1D)
 }
 
 
-void Conv4_16(WORD *Dest, const BYTE *Src, unsigned Size1D)
+void Conv4_16(uint16_t *Dest, const uint8_t *Src, unsigned Size1D)
 {
-static const WORD Conv4_16TAB[16] = { 
+static const uint16_t Conv4_16TAB[16] = { 
        0x0000, 0x1111, 0x2222, 0x3333, 0x4444, 0x5555, 0x6666, 0x7777,
        0x8888, 0x9999, 0xAAAA, 0xBBBB, 0xCCCC, 0xDDDD, 0xEEEE, 0xFFFF};
   while(Size1D>0)
@@ -202,9 +202,9 @@ static const WORD Conv4_16TAB[16] = {
 }
 
 
-void Conv4_32(DWORD *Dest, const BYTE *Src, unsigned Size1D)
+void Conv4_32(uint32_t *Dest, const uint8_t *Src, unsigned Size1D)
 {
-static const DWORD Conv4_32TAB[16] = { 
+static const uint32_t Conv4_32TAB[16] = { 
        0x00000000, 0x11111111, 0x22222222, 0x33333333, 0x44444444, 0x55555555, 0x66666666, 0x77777777,
        0x88888888, 0x99999999, 0xAAAAAAAA, 0xBBBBBBBB, 0xCCCCCCCC, 0xDDDDDDDD, 0xEEEEEEEE, 0xFFFFFFFF};
   while(Size1D>0)
@@ -222,9 +222,9 @@ static const DWORD Conv4_32TAB[16] = {
 
 /*---------- 8bit = 1byte ------------ */
 
-void Conv8_1(BYTE *Dest, const BYTE *Src, unsigned Size1D)
+void Conv8_1(uint8_t *Dest, const uint8_t *Src, unsigned Size1D)
 {
-BYTE Mask;
+uint8_t Mask;
 
   while(Size1D>0)
     {
@@ -239,14 +239,14 @@ BYTE Mask;
 }
 
 
-void Conv8_4(BYTE *Dest, const BYTE *Src, unsigned Size1D)
+void Conv8_4(uint8_t *Dest, const uint8_t *Src, unsigned Size1D)
 {
   while(Size1D>0)
     {
-    *Dest = 0xF0 & (BYTE)(*Src);
+    *Dest = 0xF0 & (uint8_t)(*Src);
     Src++;
     if(Size1D-- <= 1) break;
-    *Dest |= (BYTE)(*Src>>4);
+    *Dest |= (uint8_t)(*Src>>4);
     Src++;
     Dest++;    
     Size1D--;
@@ -254,7 +254,7 @@ void Conv8_4(BYTE *Dest, const BYTE *Src, unsigned Size1D)
 }
 
 
-void Conv8_16(WORD *Dest, const BYTE *Src, unsigned Size1D)
+void Conv8_16(uint16_t *Dest, const uint8_t *Src, unsigned Size1D)
 {
   while(Size1D-->0)
   {
@@ -263,9 +263,9 @@ void Conv8_16(WORD *Dest, const BYTE *Src, unsigned Size1D)
 }
 
 
-void Conv8_24(BYTE *Dest, const BYTE *Src, unsigned Size1D)
+void Conv8_24(uint8_t *Dest, const uint8_t *Src, unsigned Size1D)
 {
-BYTE b;
+uint8_t b;
   while(Size1D-->0)
   {
     b = *Src++;
@@ -276,7 +276,7 @@ BYTE b;
 }
 
 
-void Conv8_32(DWORD *Dest, const BYTE *Src, unsigned Size1D)
+void Conv8_32(uint32_t *Dest, const uint8_t *Src, unsigned Size1D)
 {
   while(Size1D-->0)
   {
@@ -285,8 +285,8 @@ void Conv8_32(DWORD *Dest, const BYTE *Src, unsigned Size1D)
 }
 
 
-#ifdef QWORD
-void Conv8_64(QWORD *Dest, const BYTE *Src, unsigned Size1D)
+#if defined(uint64_t) || defined(uint64_t_defined)
+void Conv8_64(uint64_t *Dest, const uint8_t *Src, unsigned Size1D)
 {
   while(Size1D-->0)
   {
@@ -299,9 +299,9 @@ void Conv8_64(QWORD *Dest, const BYTE *Src, unsigned Size1D)
 /*---------- 16bit = 2byte ------------ */
 
 
-void Conv16_1(BYTE *Dest, const WORD *Src, unsigned Size1D)
+void Conv16_1(uint8_t *Dest, const uint16_t *Src, unsigned Size1D)
 {
-BYTE Mask;
+uint8_t Mask;
 
   while(Size1D>0)
     {
@@ -316,14 +316,14 @@ BYTE Mask;
 }
 
 
-void Conv16_4(BYTE *Dest, const WORD *Src, unsigned Size1D)
+void Conv16_4(uint8_t *Dest, const uint16_t *Src, unsigned Size1D)
 {
   while(Size1D>0)
     {
-    *Dest = 0xF0 & (BYTE)(*Src >> 8);
+    *Dest = 0xF0 & (uint8_t)(*Src >> 8);
     Src++;
     if(Size1D-- <= 1) break;
-    *Dest |= (BYTE)(*Src>>12);
+    *Dest |= (uint8_t)(*Src>>12);
     Src++;
     Dest++;    
     Size1D--;
@@ -331,7 +331,7 @@ void Conv16_4(BYTE *Dest, const WORD *Src, unsigned Size1D)
 }
 
 
-void Conv16_8(BYTE *Dest, const WORD *Src, unsigned Size1D)
+void Conv16_8(uint8_t *Dest, const uint16_t *Src, unsigned Size1D)
 {
   while(Size1D-->0)
     {
@@ -340,9 +340,9 @@ void Conv16_8(BYTE *Dest, const WORD *Src, unsigned Size1D)
 }
 
 
-void Conv16_24(BYTE *Dest, const WORD *Src, unsigned Size1D)
+void Conv16_24(uint8_t *Dest, const uint16_t *Src, unsigned Size1D)
 {
-WORD w;
+uint16_t w;
   while(Size1D-->0)
   {
     w = *Src++;
@@ -352,7 +352,7 @@ WORD w;
   }
 }
 
-void Conv16_32(DWORD *Dest, const WORD *Src, unsigned Size1D)
+void Conv16_32(uint32_t *Dest, const uint16_t *Src, unsigned Size1D)
 {
   while(Size1D-->0)
     {
@@ -361,8 +361,8 @@ void Conv16_32(DWORD *Dest, const WORD *Src, unsigned Size1D)
 }
 
 
-#ifdef QWORD
-void Conv16_64(QWORD *Dest, const WORD *Src, unsigned Size1D)
+#if defined(uint64_t) || defined(uint64_t_defined)
+void Conv16_64(uint64_t *Dest, const uint16_t *Src, unsigned Size1D)
 {
   while(Size1D-->0)
   {
@@ -376,7 +376,7 @@ void Conv16_64(QWORD *Dest, const WORD *Src, unsigned Size1D)
 /*--------------------------------- */
 
 
-void Conv24_8(BYTE *Dest, const BYTE *Src, unsigned Size1D)
+void Conv24_8(uint8_t *Dest, const uint8_t *Src, unsigned Size1D)
 {
   Src += 2;		/* point to 3rd byte.*/
   while(Size1D-->0)
@@ -387,7 +387,7 @@ void Conv24_8(BYTE *Dest, const BYTE *Src, unsigned Size1D)
 }
 
 
-void Conv24_16(WORD *Dest, const BYTE *Src, unsigned Size1D)
+void Conv24_16(uint16_t *Dest, const uint8_t *Src, unsigned Size1D)
 {
   Src += 1;		/* point to 3rd byte.*/
   while(Size1D-->0)
@@ -398,7 +398,7 @@ void Conv24_16(WORD *Dest, const BYTE *Src, unsigned Size1D)
 }
 
 
-void Conv24_32(DWORD *Dest, const BYTE *Src, unsigned Size1D)
+void Conv24_32(uint32_t *Dest, const uint8_t *Src, unsigned Size1D)
 {
   while(Size1D-->0)
   {    
@@ -408,8 +408,8 @@ void Conv24_32(DWORD *Dest, const BYTE *Src, unsigned Size1D)
 }
 
 
-#ifdef QWORD
-void Conv24_64(QWORD *Dest, const BYTE *Src, unsigned Size1D)
+#if defined(uint64_t) || defined(uint64_t_defined)
+void Conv24_64(uint64_t *Dest, const uint8_t *Src, unsigned Size1D)
 {
   while(Size1D-->0)
   {    
@@ -423,9 +423,9 @@ void Conv24_64(QWORD *Dest, const BYTE *Src, unsigned Size1D)
 /*--------------------------------- */
 
 
-void Conv32_1(BYTE *Dest, const DWORD *Src, unsigned Size1D)
+void Conv32_1(uint8_t *Dest, const uint32_t *Src, unsigned Size1D)
 {
-BYTE Mask;
+uint8_t Mask;
 
   while(Size1D>0)
     {
@@ -440,14 +440,14 @@ BYTE Mask;
 }
 
 
-void Conv32_4(BYTE *Dest, const DWORD *Src, unsigned Size1D)
+void Conv32_4(uint8_t *Dest, const uint32_t *Src, unsigned Size1D)
 {
   while(Size1D>0)
     {
-    *Dest = 0xF0 & (BYTE)(*Src >> 24);
+    *Dest = 0xF0 & (uint8_t)(*Src >> 24);
     Src++;
     if(Size1D-- <= 1) break;
-    *Dest |= (BYTE)(*Src>>28);
+    *Dest |= (uint8_t)(*Src>>28);
     Src++;
     Dest++;    
     Size1D--;
@@ -455,7 +455,7 @@ void Conv32_4(BYTE *Dest, const DWORD *Src, unsigned Size1D)
 }
 
 
-void Conv32_8(BYTE *Dest, const DWORD *Src, unsigned Size1D)
+void Conv32_8(uint8_t *Dest, const uint32_t *Src, unsigned Size1D)
 {
   while(Size1D-->0)
     {
@@ -463,7 +463,7 @@ void Conv32_8(BYTE *Dest, const DWORD *Src, unsigned Size1D)
     }
 }
 
-void Conv32_16(WORD *Dest, const DWORD *Src, unsigned Size1D)
+void Conv32_16(uint16_t *Dest, const uint32_t *Src, unsigned Size1D)
 {
   while(Size1D-->0)
     {
@@ -472,7 +472,7 @@ void Conv32_16(WORD *Dest, const DWORD *Src, unsigned Size1D)
 }
 
 
-void Conv32_24(BYTE *Dest, const DWORD *Src, unsigned Size1D)
+void Conv32_24(uint8_t *Dest, const uint32_t *Src, unsigned Size1D)
 {
   while(Size1D-->0)
     {
@@ -484,8 +484,8 @@ void Conv32_24(BYTE *Dest, const DWORD *Src, unsigned Size1D)
 }
 
 
-#ifdef QWORD
-void Conv32_64(QWORD *Dest, const DWORD *Src, unsigned Size1D)
+#if defined(uint64_t) || defined(uint64_t_defined)
+void Conv32_64(uint64_t *Dest, const uint32_t *Src, unsigned Size1D)
 {
   while(Size1D-->0)
   {
@@ -498,7 +498,7 @@ void Conv32_64(QWORD *Dest, const DWORD *Src, unsigned Size1D)
 /*********  ***********/
 
 #if 0
-void SetValue1(BYTE *b, unsigned x, DWORD NewValue)
+void SetValue1(uint8_t *b, unsigned x, uint32_t NewValue)
 {
  b+= x >> 3;
  if(NewValue==0) *b = *b & ~(0x80 >>(x & 0x07));
@@ -506,7 +506,7 @@ void SetValue1(BYTE *b, unsigned x, DWORD NewValue)
 }
 
 
-DWORD GetValue1(const BYTE *b, unsigned x)
+uint32_t GetValue1(const uint8_t *b, unsigned x)
 {
  if(b==NULL) return(0);
  b+= x >> 3;
@@ -515,9 +515,9 @@ DWORD GetValue1(const BYTE *b, unsigned x)
 }
 
 
-void SetValue2(BYTE *b, unsigned x, DWORD NewValue)
+void SetValue2(uint8_t *b, unsigned x, uint32_t NewValue)
 {
-BYTE v;
+uint8_t v;
 
  v = NewValue;
  if(NewValue>3) v=3;
@@ -533,7 +533,7 @@ BYTE v;
 }
 
 
-DWORD GetValue2(const BYTE *b, unsigned x)
+uint32_t GetValue2(const uint8_t *b, unsigned x)
 {
  if(b==NULL) return 0;
  b+= x >> 2;
@@ -550,7 +550,7 @@ return 0;
 
 /* ------------- 4 bit planes ------------- */
 
-void SetValue4(BYTE *b, unsigned x, DWORD NewValue)
+void SetValue4(uint8_t *b, unsigned x, uint32_t NewValue)
 {
  if(b==NULL) return;
  b+= x >> 1;
@@ -559,7 +559,7 @@ void SetValue4(BYTE *b, unsigned x, DWORD NewValue)
 }
 
 
-DWORD GetValue4(const BYTE *b, unsigned x)
+uint32_t GetValue4(const uint8_t *b, unsigned x)
 {
  if(b==NULL) return 0;
  b+= x >> 1;
@@ -571,7 +571,7 @@ DWORD GetValue4(const BYTE *b, unsigned x)
 /* -------------- 8 bit planes ---------------- */
 
 
-void SetValue8(BYTE *b, unsigned x, DWORD NewValue)
+void SetValue8(uint8_t *b, unsigned x, uint32_t NewValue)
 {
  if(b==NULL) return;
  if(NewValue>0xFF) b[x] = 0xFF;
@@ -579,7 +579,7 @@ void SetValue8(BYTE *b, unsigned x, DWORD NewValue)
 }
 
 
-DWORD GetValue8(const BYTE *b, unsigned x)
+uint32_t GetValue8(const uint8_t *b, unsigned x)
 {
  if(b==NULL) return 0;
  return b[x];
@@ -588,28 +588,28 @@ DWORD GetValue8(const BYTE *b, unsigned x)
 
 /* ------------- 16 bit planes -------------- */
 
-void SetValue16(BYTE *b, unsigned x, DWORD NewValue)
+void SetValue16(uint8_t *b, unsigned x, uint32_t NewValue)
 {
  if(b==NULL) return;
- ((WORD *)b)[x] = NewValue;
+ ((uint16_t *)b)[x] = NewValue;
 }
 
 
-DWORD GetValue16(const BYTE *b, unsigned x)
+uint32_t GetValue16(const uint8_t *b, unsigned x)
 {
  if(b==NULL) return 0;
- return ((WORD *)b)[x];
+ return ((uint16_t *)b)[x];
 }
 
 /* ------------- 24 bit planes -------------- */
 
-DWORD GetValue24(const BYTE *b, unsigned x)
+uint32_t GetValue24(const uint8_t *b, unsigned x)
 {
  b += (3*x);
- return (DWORD)*b | (DWORD)b[1]<<8 | (DWORD)b[2]<<16;
+ return (uint32_t)*b | (uint32_t)b[1]<<8 | (uint32_t)b[2]<<16;
 }
 
-void SetValue24(BYTE *b, int x, DWORD NewValue)
+void SetValue24(uint8_t *b, int x, uint32_t NewValue)
 {
  b += 3*x; 
  *b++ = NewValue & 0xFF;
@@ -624,10 +624,10 @@ void SetValue24(BYTE *b, int x, DWORD NewValue)
 /********* Flips ***********/
 
 
-void Flip1(BYTE *b, unsigned len)
+void Flip1(uint8_t *b, unsigned len)
 {
-  BYTE Mask1, Mask2;
-  BYTE *b2;
+  uint8_t Mask1, Mask2;
+  uint8_t *b2;
   if(len<=1) return;	// Prevent underflow 0-1
   len--;
 
@@ -675,10 +675,10 @@ void Flip1(BYTE *b, unsigned len)
 }
 
 
-void Flip4(BYTE *b, unsigned len)
+void Flip4(uint8_t *b, unsigned len)
 {
-BYTE *b2;
-register BYTE tmp;
+uint8_t *b2;
+register uint8_t tmp;
 
  if(b==NULL || len<=1) return;
 
@@ -719,10 +719,10 @@ register BYTE tmp;
 
 
 /** Inplace flip for 8 bits. */
-void Flip8(BYTE *b, unsigned len)
+void Flip8(uint8_t *b, unsigned len)
 {
-BYTE *b2;
-register BYTE tmp;
+uint8_t *b2;
+register uint8_t tmp;
 
  if(b==NULL || len<=1) return;
 
@@ -736,10 +736,10 @@ register BYTE tmp;
    }
 }
 
-void Flip16(WORD *w, unsigned len)
+void Flip16(uint16_t *w, unsigned len)
 {
-WORD *w2;
-register WORD tmp;
+uint16_t *w2;
+register uint16_t tmp;
 
  if(w==NULL || len<=1) return;
 
@@ -754,10 +754,10 @@ register WORD tmp;
 }
 
 
-void Flip24(BYTE *b, unsigned len)
+void Flip24(uint8_t *b, unsigned len)
 {
-BYTE *b2;
-register BYTE tmp;
+uint8_t *b2;
+register uint8_t tmp;
 
  if(b==NULL || len<=1) return;
 
@@ -773,10 +773,10 @@ register BYTE tmp;
 }
 
 
-void Flip32(DWORD *d, unsigned len)
+void Flip32(uint32_t *d, unsigned len)
 {
-DWORD *d2;
-register DWORD tmp;
+uint32_t *d2;
+register uint32_t tmp;
 
  if(d==NULL || len<=1) return;
 
@@ -791,11 +791,11 @@ register DWORD tmp;
 }
 
 
-#ifdef QWORD
-void Flip64(QWORD *q, unsigned len)
+#if defined(uint64_t) || defined(uint64_t_defined)
+void Flip64(uint64_t *q, unsigned len)
 {
-QWORD *q2;
-register QWORD tmp;
+uint64_t *q2;
+register uint64_t tmp;
 
  if(q==NULL || len<=1) return;
 
@@ -808,7 +808,7 @@ register QWORD tmp;
    q++; q2--;
    }
 }
-#endif /* QWORD */
+#endif /* uint64_t */
 
 
 
