@@ -7,6 +7,7 @@
  ******************************************************************************/
 #include <stdlib.h>
 #include <stdio.h>
+#define _USE_MATH_DEFINES
 #include <math.h>
 
 #include "matrix.h"
@@ -189,6 +190,7 @@ PS_State::PS_State(void)
   memset(&FillBackground, 0xFF, sizeof(FillBackground)); //Use white paper.
   pPalette = NULL;
   pRaster = NULL;
+  inPath = 0;
 }
 
 
@@ -276,7 +278,7 @@ void vecPen::prepExport(PS_State *PSS) const
     if(memcmp(&LineColor,&PSS->LineColor,sizeof(RGB_Record)) != 0) 
     {
       memcpy(&PSS->LineColor,&LineColor,sizeof(RGB_Record));
-      PSS->dirty |= PSS_LineColor;      
+      PSS->dirty |= PSS_LineColor;
     }
     if(PSS->LineStyle != LineStyle)
     {
@@ -596,15 +598,7 @@ string str;
 			 fabs(RightRect-LeftRect)/2, fabs(TopRect-BottomRect)/2,
 			 bAngle, eAngle);
 
-  if(BrushStyle!=FILL_NONE)
-  {
-    FillObjectPS(LeftRect,RightRect,BottomRect,TopRect,str,PSS);
-  }
-  else
-  {    
-    str += "\nstroke";
-  }
-
+  FillObjectPS(LeftRect,RightRect,BottomRect,TopRect,str,PSS);
   if(ContextSaved) str += "\ngrestore";
 
 return temp_string(str);
@@ -667,14 +661,7 @@ string str;
 			 bAngle, eAngle);
   //str.cat_printf("\n%2.2f %2.2f lineto", (RightRect+LeftRect)/2, (TopRect+BottomRect)/2);
 
-  if(BrushStyle!=FILL_NONE)
-  {
-    FillObjectPS(LeftRect,RightRect,BottomRect,TopRect,str,PSS);
-  }
-  else
-  {    
-    str += "\nstroke";
-  }
+  FillObjectPS(LeftRect,RightRect,BottomRect,TopRect,str,PSS);
 
   if(ContextSaved) str += "\ngrestore";
 
@@ -772,14 +759,7 @@ float x, y;
   str.cat_printf("\n%2.2f %2.2f lineto", x, y);
   str.cat_printf("\nclosepath");
 
-  if(BrushStyle!=FILL_NONE)
-  {
-    FillObjectPS(LeftRect,RightRect,BottomRect,TopRect,str,PSS);
-  }
-  else
-  {    
-    str += "\nstroke";
-  }  
+  FillObjectPS(LeftRect,RightRect,BottomRect,TopRect,str,PSS);
 
 return temp_string(str);
 }
@@ -861,7 +841,7 @@ bool ContextSaved = false;
 
   if(PSS != NULL)
   {
-    vecBrush::prepExport(PSS);    
+    vecBrush::prepExport(PSS);
     vecPen::prepExport(PSS);
     PS_Attr(PSData, PSS);
   }
@@ -910,14 +890,6 @@ void VectorRectangleArc::Dump2File(FILE *F) const
 /////////////////////////////////////////////////////////////
 
 
-/*
-VectorPolygon::VectorPolygon(float *iniPoints, int iniPointCount): VectorLine(iniPoints,iniPointCount)
-{
-//  Outline = true;
-}
-*/
-
-
 temp_string VectorPolygon::Export2EPS(PS_State *PSS) const
 {
 string str;
@@ -925,23 +897,26 @@ string str;
 
   if(PSS != NULL)
   {
-    vecBrush::prepExport(PSS);
-    vecPen::prepExport(PSS);
-    PS_Attr(str,PSS);
-    if(PSS->PolyFillMode==1 && UpperCont!=NULL && CountPoints>=3)
+    if(PSS->inPath <=0)
     {
-      unsigned IntersectCount=0;
-      const VectorObject *vec = UpperCont->FirstObject;
-      while(vec!=NULL)
+      vecBrush::prepExport(PSS);
+      vecPen::prepExport(PSS);
+      PS_Attr(str,PSS);
+      if(PSS->PolyFillMode==1 && UpperCont!=NULL && CountPoints>=3)
       {
-        if(vec==this) break;
-        IntersectCount += vec->isInside(Points[0],Points[1]);
-        if(vec==UpperCont->LastObject) break;
-        vec = vec->NextObject;
-      }
-      if((IntersectCount & 3) == 2)
-      {
-        PSS->FirstTimeFix = true;	// Flip foreground to background.
+        unsigned IntersectCount=0;
+        const VectorObject *vec = UpperCont->FirstObject;
+        while(vec!=NULL)
+        {
+          if(vec==this) break;
+          IntersectCount += vec->isInside(Points[0],Points[1]);
+          if(vec==UpperCont->LastObject) break;
+          vec = vec->NextObject;
+        }
+        if((IntersectCount & 3) == 2)
+        {
+          PSS->FirstTimeFix = true;	// Flip foreground to background.
+        }
       }
     }
   }
@@ -958,13 +933,17 @@ string str;
     if(y<MinPolyY) MinPolyY=y;
     if(y>MaxPolyY) MaxPolyY=y;
 
-    str.cat_printf(p==Points?"\nnewpath\n%2.2f %2.2f moveto":"\n%2.2f %2.2f lineto",
+    if(p==Points && PSS!=NULL && PSS->inPath>=2) continue;
+    str.cat_printf(p==Points ? "\nnewpath\n%2.2f %2.2f moveto" : "\n%2.2f %2.2f lineto",
 		    x, y);
   }
-  if(Close) str += "\nclosepath";
-  
-  FillObjectPS(MinPolyX,MaxPolyX,MinPolyY,MaxPolyY,str,PSS);
+
+  if(PSS==NULL || PSS->inPath<=0)
+  {
+    if(Close) str += "\nclosepath";
   
+    FillObjectPS(MinPolyX,MaxPolyX,MinPolyY,MaxPolyY,str,PSS);
+  }
   return temp_string(str);
 }
 
@@ -1211,15 +1190,20 @@ float *p = Points;
     p += 2;		// point to anchor points.
   }
 
-  if(PSS != NULL)
+  if(PSS!=NULL)
   {
-    vecPen::prepExport(PSS);
-    if(Filled && BrushStyle!=FILL_NONE)
-        vecBrush::prepExport(PSS);
-    PS_Attr(str,PSS);
+    if(PSS->inPath<=0)
+    {
+      vecPen::prepExport(PSS);
+      if(/*Filled &&*/ BrushStyle!=FILL_NONE)
+          vecBrush::prepExport(PSS);
+      PS_Attr(str,PSS);
+    }
+    if(PSS->inPath>1) goto SkipNewPath;
   }
   
   str.cat_printf("\nnewpath\n%2.2f %2.2f moveto", *p, p[1]);
+SkipNewPath:
   MinPolyX = MaxPolyX = *p;	// Control point
   MinPolyY = MaxPolyY = p[1];
 
@@ -1261,15 +1245,18 @@ float *p = Points;
     }
   }
 
-  if(Filled && BrushStyle!=FILL_NONE)
+  if(PSS==NULL || PSS->inPath<=0)
   {
-    str += "\nclosepath";
-    FillObjectPS(MinPolyX,MaxPolyX,MinPolyY,MaxPolyY,str,PSS);
-  }
-  else
-  {
-    if(Close) str += "\nclosepath";
-    str += "\nstroke"; 
+    if(/*Filled &&*/ BrushStyle!=FILL_NONE)
+    {
+      str += "\nclosepath";
+      FillObjectPS(MinPolyX,MaxPolyX,MinPolyY,MaxPolyY,str,PSS);
+    }
+    else
+    {
+      if(Close) str += "\nclosepath";
+      str += "\nstroke"; 
+    }
   }
   return temp_string(str);
 }
@@ -1355,13 +1342,19 @@ string str;
 	// There must be at least two points for the line.
   if(Points==NULL || CountPoints<=1) return temp_string();
 
-  if(PSS != NULL)
-  {    
-    vecPen::prepExport(PSS);
-    PS_Attr(str,PSS);
+  if(PSS!=NULL)
+  {
+    if(PSS->inPath <= 0)
+    {
+      vecPen::prepExport(PSS);
+      PS_Attr(str,PSS);
+    }
+    else
+      if(PSS->inPath >= 2) goto SkipMoveTo;
   }
 
   str.cat_printf("\nnewpath\n%2.2f %2.2f moveto", *Points, Points[1]);
+SkipMoveTo:
 
   float *p;
   const float *pEnd = Points + 2*CountPoints;
@@ -1369,8 +1362,12 @@ string str;
   {
     str.cat_printf("\n%2.2f %2.2f lineto", *p, p[1]);
   }
-  if(Close) str += "\nclosepath";
-  str += "\nstroke"; 
+
+  if(PSS==NULL || PSS->inPath <=0)
+  {
+    if(Close) str += "\nclosepath";
+    str += "\nstroke";
+  }
   return temp_string(str);
 }
 
@@ -1624,6 +1621,87 @@ return false;
 /////////////////////////////////////////////////////////////
 
 
+temp_string VectorPath::Export2EPS(PS_State *PSS) const
+{
+string str;
+VectorObject *IterObject = FirstObject;
+
+  if(IterObject==NULL) return("");
+  if(PSS)
+  {
+    vecBrush::prepExport(PSS);
+    vecPen::prepExport(PSS);
+    PS_Attr(str,PSS);
+    PSS->inPath = 1;
+  }
+  while(IterObject!=NULL)
+  {
+    str += IterObject->Export2EPS(PSS);
+    IterObject = IterObject->NextObject;
+    if(PSS) PSS->inPath = 2;
+  }
+  if(PSS)
+  {
+    if(Close) str += "\nclosepath";
+    if(PSS->FillPattern==FILL_NONE)
+      str += "\nstroke";
+    else
+    {
+      FloatBBox bbx;
+      CalcBoundingBox(bbx);
+      InitBBox(bbx);
+      FillObjectPS(bbx.MinX,bbx.MaxX,bbx.MinY,bbx.MaxY,str,PSS);
+    }
+    PSS->inPath = 0;
+  }
+  return temp_string(str);
+}
+
+
+void VectorPath::Export2EPS(FILE *F, PS_State *PSS) const
+{
+VectorObject *IterObject = FirstObject;
+  if(F==NULL || IterObject==NULL) return;
+
+  if(PSS)
+  {
+    string str;
+    vecBrush::prepExport(PSS);
+    vecPen::prepExport(PSS);
+    PS_Attr(str,PSS);
+    PSS->inPath = 1;
+    if(!str.isEmpty())
+        fwrite(str(),str.length(),1,F);
+  }
+  while(IterObject!=NULL)
+  {
+    IterObject->Export2EPS(F,PSS);
+    IterObject = IterObject->NextObject;
+    if(PSS) PSS->inPath = 2;
+  }
+  if(PSS)
+  {
+    if(Close) fputs("\nclosepath",F);
+    if(PSS->FillPattern==FILL_NONE)
+      fputs("\nstroke",F);
+    else
+    {
+      string str;
+      FloatBBox bbx;
+      CalcBoundingBox(bbx);
+      InitBBox(bbx);
+      FillObjectPS(bbx.MinX,bbx.MaxX,bbx.MinY,bbx.MaxY,str,PSS);
+      if(!str.isEmpty())
+        fwrite(str(),str.length(),1,F);
+    }
+    PSS->inPath = 0;
+  }
+}
+
+
+/////////////////////////////////////////////////////////////
+
+
 VectorImage::VectorImage(VectorList &VecList, const PS_State & NewPSS): PSS(NewPSS)
 {
   //PSS = NewPSS;
@@ -1865,7 +1943,7 @@ string Override;
 
         if(i==0)
         {
-          str.cat_printf("\nnewpath %2.2f %2.2f moveto", CurPosX, CurPosY);         
+          str.cat_printf("\nnewpath %2.2f %2.2f moveto", CurPosX, CurPosY);
         }
 
         char *ScanS = Text[i]->contents();
@@ -2005,10 +2083,23 @@ void TextContainer::Transform(const AbstractTransformXY &Tx)
 {
   RotCenterX += PosX;
   RotCenterY += PosY;
+
+  float ScaleX=RotCenterX+0.1, ScaleY=RotCenterY+0.1;
+  Tx.ApplyTransform(ScaleX, ScaleY);
+
   Tx.ApplyTransform(RotCenterX, RotCenterY);
+  ScaleX = fabs(RotCenterX-ScaleX) / 0.1;	// This is translation invariant.
+
   Tx.ApplyTransform(PosX, PosY);
   RotCenterX -= PosX;
   RotCenterY -= PosY;
+
+	// Scale also font size.
+  for(int i=0; i<TextObjects; i++)
+  {
+    if(Text[i]==NULL) continue;
+    Text[i]->size *= ScaleX;
+  }
 }
 
 
@@ -2186,6 +2277,8 @@ const char *pos;
 }
 
 
+/** Calculate amount of lines in a given text blob.
+ * @return	Amount oflines. */
 int LineCountTxt(const char *Txt)
 {
 int LineCount = 1;
@@ -2199,7 +2292,8 @@ int LineCount = 1;
 }
 
 
-/** Convert accents to PS equivalents. */
+/** Convert accents to PS equivalents.
+ * @param[in,out]	s	EPS string to be fixed. */
 static void FixPsSymbol(string & s, const char *TeXSymb, const char PSsymb,
                         const string &CurrentFont, const string &SymbolFont)
 {
@@ -2229,7 +2323,7 @@ const char *pos;
    Text2 += CurrentFont;
    pos += StrLen(TeXSymb);
 
-   Text2 += " (";   
+   Text2 += " (";
    if(*pos!=0)
      Text2 += pos;		// Append a rest of the string.
 
@@ -2301,7 +2395,7 @@ void FillObjectPS(float MinPolyX, float MaxPolyX, float MinPolyY, float MaxPolyY
 string tmp, color;
 float Distance;
 
-  if(PSS==NULL)
+  if(PSS==NULL || PSS->FillPattern==FILL_NONE)
   {
     PSData += "\nstroke";		//draw frame line
     return;
