@@ -103,24 +103,25 @@ typedef struct
 
 	uint16_t FontWeight;
 	int16_t FontOrientation10;	///< Text rotation request.
-        
+
 	char FontItallic;
 	char dirty;
 	uint8_t FillPattern;
-        uint8_t FillTransparency;
+	uint8_t FillTransparency;
 	uint8_t LineStyle;
-	uint8_t LineCap;			///< 0-butt caps, 1-round caps, 2-extended butt caps.
-	uint8_t LineJoin;			///< 0-miter join, 1-round join, 2-bevel join.
-        uint8_t PolyFillMode;		///< 0-standard; 1-alternating
+	uint8_t LineCap;		///< 0-butt caps, 1-round caps, 2-extended butt caps.
+	uint8_t LineJoin;		///< 0-miter join, 1-round join, 2-bevel join.
+	uint8_t PolyFillMode;		///< 0-standard; 1-alternating
 	uint8_t TextAllign;		///< 0-TA_LEFT; 2-TA_RIGHT; 6-TA_CENTER
 
 	RGB_Record FillColor;	
-        RGB_Record FillBackground;
+	RGB_Record FillBackground;
 
 	RGB_Record LineColor;
 	RGB_Record TextColor;
 	
-        bool FirstTimeFix;
+	bool FirstTimeFix;
+	uint8_t inPath;
 } PS_StateC;
 
 
@@ -350,7 +351,7 @@ class VectorList: public VectorObject
 {
 public:
   virtual temp_string Export2EPS(PS_State *PSS=NULL) const;
-  void Export2EPS(FILE *F, PS_State *PSS=NULL) const;
+  virtual void Export2EPS(FILE *F, PS_State *PSS=NULL) const;
   virtual void FeaturesEPS(uint32_t & Feature) const;
 #ifdef _DEBUG
   virtual void Dump2File(FILE *F) const;
@@ -373,6 +374,18 @@ public:
 };
 
 
+class VectorPath: public VectorList, public vecPen, public vecBrush
+{
+public:
+  bool Close;
+
+  VectorPath(void): Close(false) {};
+
+  virtual temp_string Export2EPS(PS_State *PSS=NULL) const;
+  void Export2EPS(FILE *F, PS_State *PSS) const;
+};
+
+
 class VectorEllipse: public VectorObject, public vecPen, public vecBrush
 {
 public:
@@ -425,18 +438,19 @@ public:
 };
 
 
+/// Vector curve has possiblitity to fill curved area with solid color or hachched.
 class VectorCurve: public VectorLine, public vecBrush
 {
 public:
-  VectorCurve(int iniPointCount): VectorLine(iniPointCount) {Filled=false;};
-  VectorCurve(float *iniBottomRect, int iniPointCount): VectorLine(iniBottomRect,iniPointCount) {Filled=false;};
-  VectorCurve(const VectorCurve &VC): VectorLine(VC), vecBrush(VC) {Filled=VC.Filled;}
+  VectorCurve(int iniPointCount): VectorLine(iniPointCount) {BrushStyle=FILL_NONE;};
+  VectorCurve(float *iniBottomRect, int iniPointCount): VectorLine(iniBottomRect,iniPointCount) {BrushStyle=FILL_NONE;};
+  VectorCurve(const VectorCurve &VC): VectorLine(VC), vecBrush(VC) {}
 
   virtual void CalcBoundingBox(FloatBBox &bbx) const;
   void AttribFromPSS(const PS_State &PSS) {vecPen::AttribFromPSS(PSS);vecBrush::AttribFromPSS(PSS);}
   virtual temp_string Export2EPS(PS_State *PSS=NULL) const;
 
-  bool Filled;		// This should be replaced with BrushStyle=FILL_NONE.
+  //bool Filled;		// This should be replaced with BrushStyle=FILL_NONE.
 };
 
 
