@@ -350,13 +350,19 @@ char RasterPlanes;
    case ImageTrueColor:
 	   if(RasterPlanes==24) goto FAST_COPY;
 	   {
-	     Raster1DAbstract *RasLine = Raster->GetRowRaster(Y);	  
+	     Raster1DAbstract *RasLine = Raster->GetRowRaster(Y);
 	     if(RasLine)
 	       {
-	       uint32_t w;
-	       for(X=0;X<RasLine->GetSize1D();X++)
+	       uint16_t chars_on_line = 0;
+	       for(X=0; X<RasLine->GetSize1D(); X++)
 		 {
-	         w = RasLine->GetValue1D(X);	      
+	         const uint32_t w = RasLine->GetValue1D(X);
+		 chars_on_line += 6;
+		 if(chars_on_line>253)
+		 {
+		   fputs("\r\n",f);
+		   chars_on_line = 6;
+		 }
 	         fprintf(f,"%.2X%.2X%.2X", w&0xFF, (w>>8)&0xFF, (w>>16)&0xFF);
 	         }
                }
