@@ -1,5 +1,5 @@
 /** Suport for parallel task processing on multiple CPUs.
- * (c) 2013 - 2020 Jaroslav Fojtik.
+ * (c) 2013 - 2023 Jaroslav Fojtik.
  * This code could be distributed under LGPL licency. */
 #include "jobs.h"
 #include <stdio.h>
@@ -38,6 +38,9 @@ JobBase::JobBase()
   InterlockedIncrement(&JobCount);
 }
 
+
+///< Job dtor should cleanup all resources used by job child.
+///< This one only decrements amount of queued jobs.
 JobBase::~JobBase()
 {
   InterlockedDecrement(&JobCount);
@@ -46,8 +49,8 @@ JobBase::~JobBase()
 
 CRITICAL_SECTION jobs_cs;
 
-int WorkersRunning = 0;		///< Amount of asynchronnous workers running.
-JobBase **JOB_CACHE = NULL;
+volatile int WorkersRunning = 0;	///< Amount of asynchronnous workers running.
+JobBase **JOB_QUEUE = NULL;
 
 #ifdef _WIN32
  HANDLE JobAlertEvent;
@@ -70,26 +73,30 @@ JobBase *JOB = NULL;
   while(WorkersRunning>0)
   {
     //printf(">>Wake %u<<", GetCurrentThreadId());
+
+	// Lease a job
     EnterCriticalSection(&jobs_cs);
     for(i=0; i<WorkersRunning; i++)
       {
-      if(JOB_CACHE[i]!=NULL)
+      if(JOB_QUEUE[i]!=NULL)
           {
-          JOB = JOB_CACHE[i];
-          JOB_CACHE[i] = NULL;
+          JOB = JOB_QUEUE[i];
+          JOB_QUEUE[i] = NULL;
 	  break;
 	  }
       }
     LeaveCriticalSection(&jobs_cs);
 
+	// Do the job
     if(JOB)
       {
       JOB->Run();
       delete JOB;
       JOB = NULL;
-      continue;
-      }    
+      continue;		// When job is done, lease another job.
+      }   
 
+	// Wait for allerting
 #ifdef _WIN32
     WaitForSingleObject(JobAlertEvent, POOLING_TIMEOUTms);
 #else
@@ -111,8 +118,12 @@ JobBase *JOB = NULL;
 }
 
 
+/** Initialise jobs infrastructure.
+ * @param[in]	ThrCount	Thread count	1,2,3,6; or 0 no additional thread; or <0 autodetect threads.
+ * @return	<0 failure; 1 OK */
 int InitJobs(int ThrCount)
 {
+	// Resolve thread count.
   if(ThrCount<0)
     {
     const char *str = getenv("OMP_NUM_THREADS");
@@ -129,38 +140,45 @@ int InitJobs(int ThrCount)
       }
     }
 
+  JOB_QUEUE = (JobBase **)calloc(ThrCount,sizeof(JobBase*));
+  if(JOB_QUEUE==NULL) return -2;
   InitializeCriticalSection(&jobs_cs);
-  JOB_CACHE = (JobBase **)calloc(ThrCount,sizeof(JobBase*));
 
 #ifdef _WIN32
   if((JobAlertEvent=CreateEvent(NULL, FALSE, FALSE, NULL)) == 0)
   {
     printf("Cannot create alert event.");
-    return -2;
+    return -3;
   }
 #else
   pthread_cond_init(&JobAlertEvent, NULL);
   pthread_mutex_init(&mtx_JobAlertEvent, NULL);
 #endif
 
-  for(WorkersRunning=0; WorkersRunning<ThrCount; WorkersRunning++)
+  while(WorkersRunning<ThrCount)
   {
+     WorkersRunning++;	// Should be initialised now, newly started thread needs this value > 0.
 #ifdef _WIN32
-     HANDLE thread;
-     thread = (HANDLE)_beginthreadex(NULL,0,&JobThread,0,0,NULL);
+     const HANDLE thread = (HANDLE)_beginthreadex(NULL,0,&JobThread,0,0,NULL);
+     if(thread==0 || (size_t)thread==~0)
 #else
      pthread_t WriteThread;
-     pthread_create(&WriteThread, NULL, JobThread, NULL);
+     if(pthread_create(&WriteThread, NULL, JobThread, NULL) != 0)
 #endif
+     {
+       WorkersRunning--;	// Actual worker did not start.
+       return -3;
+     }
   }
 
   return 1;
 }
 
 
-/** Add a new job to the job cache.
+/** Add a new job to the job queue.
  * @param[in]	js	Job object - it must NOT be deleted from caller.
- *                      Job will be erased asynchronously from worker thread. */
+ *                      Job will be erased asynchronously from worker thread.
+ * @return	1 job is inserted to a queue; 0 job is finished by calling thread, queue overflow; -1 no job needed. */
 int RunJob(JobBase *js)
 {
 int i;
@@ -171,9 +189,9 @@ int i;
     EnterCriticalSection(&jobs_cs);
     for(i=0; i<WorkersRunning; i++)
       {
-      if(JOB_CACHE[i]==NULL)
+      if(JOB_QUEUE[i]==NULL)
         {
-        JOB_CACHE[i] = js;
+        JOB_QUEUE[i] = js;
         LeaveCriticalSection(&jobs_cs);
         ALERT_EVENT(JobAlertEvent);	// Wake one thread.
         return 1;
@@ -194,19 +212,20 @@ int i;
  * jobs cannot be touched. */
 void FinishJobs(int WaitMs)
 {
+  if(JOB_QUEUE==NULL) return;
   ALERT_ALL(JobAlertEvent);	// Wake up any active worker.
 
   EnterCriticalSection(&jobs_cs);
   for(int i=0; i<WorkersRunning; i++)
     {
-    if(JOB_CACHE[i]!=NULL)
+    JobBase *JOB = JOB_QUEUE[i];
+    if(JOB!=NULL)
       {
-      JobBase *JOB = JOB_CACHE[i];
-      JOB_CACHE[i] = NULL;
+      JOB_QUEUE[i] = NULL;
       LeaveCriticalSection(&jobs_cs);
       JOB->Run();	// Do the job from the parent thread.
       delete JOB;
-      EnterCriticalSection(&jobs_cs);      
+      EnterCriticalSection(&jobs_cs);
       }
     }
   LeaveCriticalSection(&jobs_cs);
@@ -219,12 +238,45 @@ void FinishJobs(int WaitMs)
 }
 
 
-/** Destroy all resources used by jobs library. */
+/** Destroy all resources used by jobs library. But all existing jobs are intended to
+ * finish their work. */
 void EndJobs(void)
 {
-  FinishJobs();
+  FinishJobs();			// Finish all work.
   WorkersRunning = 0;		// Worker exit flag.
+  if(JOB_QUEUE)
+  {
+    ALERT_ALL(JobAlertEvent);	// Alert all workers.
+    free(JOB_QUEUE); JOB_QUEUE=NULL;
+  }
+}
+
+
+/** Ask jobs to finish and do not work on already scheduled activities. */
+void AbortJobs(void)
+{
+int WorkersRunningBk = WorkersRunning;
+  WorkersRunning = 0;		// Worker exit flag.
+
+  if(JOB_QUEUE==NULL) return;	// Jobs not initialised yet.
+
   ALERT_ALL(JobAlertEvent);	// Alert all workers.
+
+  EnterCriticalSection(&jobs_cs);
+  for(int i=0; i<WorkersRunningBk; i++)
+  {
+    JobBase *JOB = JOB_QUEUE[i];
+    if(JOB!=NULL)
+    {
+      JOB_QUEUE[i] = NULL;
+      LeaveCriticalSection(&jobs_cs);
+      //JOB->Run();	// Do NOT run the job.
+      delete JOB;
+      EnterCriticalSection(&jobs_cs);
+    }
+  }
+  LeaveCriticalSection(&jobs_cs);
+  free(JOB_QUEUE); JOB_QUEUE=NULL;
 }
 
 
