@@ -25,6 +25,7 @@
 #include "stringa.h"
 #include "lists.h"
 
+#include "images/raster.h"
 #include "wp2latex.h"
 #include "struct.h"
 #include "cp_lib/cptran.h"
@@ -39,12 +40,12 @@ static const char *Parts[8] = {
 
 #ifndef FINAL
 /*This procedure isn't normally called. It can be used for exploration of new objects*/
-void CrackObject(TconvertedPass1 *cq, DWORD end_of_code)
+void CrackObject(TconvertedPass1 *cq, uint32_t end_of_code)
 {
 FILE *txt;
 unsigned short i,y;
 long pos;
-DWORD len;
+uint32_t len;
 static char ss[13] = "00__Hack.txt";
 char c;
 
@@ -203,6 +204,7 @@ unsigned i;
  {
    case Cyr_Font: Cyrillic = true; break;
    case Heb_Font: cjHebrew = true; break;
+   case Georgia_Font: mxedruli = true; break;
  }
 
 return;
@@ -284,6 +286,10 @@ string s;
    {
    cq->Font = FONT_NORMAL;
    }
+ if(attr_num==Georgia_Font && cq->Font==FONT_GEORGIA)
+   {
+   cq->Font = FONT_NORMAL;
+   }
 
 return;
 }
@@ -403,7 +409,7 @@ const char *ch;
 /** Solve attributes for columns in table header.
  * @param[in]	 Attributes	Bit mask containing attributes.
  * @return 	LaTeX string that causes selected attributes to close. */
-temp_string Attributes2String(DWORD Attributes)
+temp_string Attributes2String(uint32_t Attributes)
 {
 string TexAttrib;
 			//Solve attributes for columns
@@ -518,7 +524,7 @@ void Indent(TconvertedPass1 *cq, char WP)
 #ifdef DEBUG
   fprintf(cq->log,"\n#Indent ");fflush(cq->log);
 #endif
-WORD dif, abs;
+uint16_t dif, abs;
 unsigned char b;
 
   /* check whether the section is opened */
@@ -603,7 +609,7 @@ NoIndent:
 
 
 /** This procedure converts Line numbering. */
-void LineNumbering(TconvertedPass1 *cq, BYTE LineNumbering)
+void LineNumbering(TconvertedPass1 *cq, uint8_t LineNumbering)
 {
 #ifdef DEBUG
   fprintf(cq->log,"\n#LineNumbering() ");fflush(cq->log);
@@ -779,7 +785,7 @@ inline void SkipWP6Packets(TconvertedPass1 *cq)
 #ifdef DEBUG
   fprintf(cq->log,"\n#SkipWP6Packets() ");fflush(cq->log);
 #endif
-BYTE flags,PIDs;
+uint8_t flags,PIDs;
 
  flags=fgetc(cq->wpd);
  if(feof(cq->wpd)) return;
@@ -901,6 +907,10 @@ void CharacterStr(TconvertedPass1 *cq, const char *LatexCode)
 		 {
 		 AttrOff(cq,Heb_Font);
 		 }
+	       if(cq->Font==FONT_GEORGIA)
+                 {
+		 AttrOff(cq,Georgia_Font);
+                 }
 	       cq->Font = FONT_NORMAL;
 	       fprintf(cq->strip, "\\rm ");
 	       break;
@@ -908,6 +918,10 @@ void CharacterStr(TconvertedPass1 *cq, const char *LatexCode)
 	       AttrOn(cq->attr,Cyr_Font);
 	       cq->Font = FONT_CYRILLIC;
 	       break;
+	 case FONT_GEORGIA:		//georgia font
+	       AttrOn(cq->attr,Georgia_Font);
+	       cq->Font = FONT_GEORGIA;
+	       break;
 	case FONT_HEBREW:		//hebrew font
                if(cq->envir=='c')		  // This is some problem workaround in LaTex.
 		 fprintf(cq->strip, "\\strut ");  // Why latex otherwise cannot center \begin{hebrew} \end{hebrew} block?
@@ -971,7 +985,7 @@ void Color(TconvertedPass1 *cq, signed char WP, RGBQuad *RGB)
   fprintf(cq->log,"\n#Color(%d) ",(int)WP);fflush(cq->log);
 #endif
 const char *ColorType="?";
-BYTE Red,Green,Blue;
+uint8_t Red,Green,Blue;
 
   if(colors<0 || LaTeX_Version<0x300)
 	{
@@ -1167,7 +1181,7 @@ void HLine(TconvertedPass1 *cq, signed char WP)
   fprintf(cq->log,"\n#HLine() ");fflush(cq->log);
 #endif
   unsigned char AnchorType,HorizontalPos,VerticalPos,Shading;
-  WORD Width,Length,Raise,Left;
+  uint16_t Width,Length,Raise,Left;
 
   switch(WP)
     {
@@ -1355,7 +1369,7 @@ static const char JustWP3_2WP5[4]={0,2,3,1};
 #ifdef DEBUG
   fprintf(cq->log,"\n#Justification() ");fflush(cq->log);
 #endif
-  BYTE b;
+  uint8_t b;
   const char *Direction="?";
   char OldEnvir;
 			// This is impossible to change environment for one
@@ -1483,7 +1497,7 @@ LangItem LangTable[31] =
 	        6 - specially tailored for WP6
 		other - two chars packed, to denote languege
 */
-void Language(TconvertedPass1 *cq, WORD WPx_Language)
+void Language(TconvertedPass1 *cq, uint16_t WPx_Language)
 {
 #ifdef DEBUG
   fprintf(cq->log,"\n#Language(%d) ",WPx_Language);fflush(cq->log);
@@ -1638,8 +1652,8 @@ void Page_number_position(TconvertedPass1 *cq, unsigned char WP)
   unsigned char position_code;
   const char *PgNumType="?", *PgNumAttr="";
   string PgNumAttrS;
-  DWORD Attributes;
-  BYTE Flags,IDs;
+  uint32_t Attributes;
+  uint8_t Flags,IDs;
 
   if(WP==3) fseek(cq->wpd, 1L, SEEK_CUR);
   if(WP==4) fseek(cq->wpd, 1L, SEEK_CUR);
@@ -1822,8 +1836,8 @@ void SetEndnoteNum(TconvertedPass1 *cq, unsigned char WP)
 #ifdef DEBUG
   fprintf(cq->log,"\n#SetEndnoteNum() ");fflush(cq->log);
 #endif
-  WORD OldEndNoteNum,CurEndNoteNum;
-  BYTE Flag,NumID;
+  uint16_t OldEndNoteNum,CurEndNoteNum;
+  uint8_t Flag,NumID;
 
 
   switch(WP)
@@ -1914,7 +1928,7 @@ void SetFontSize(TconvertedPass1 *cq, char WP)
 #ifdef DEBUG
   fprintf(cq->log,"\n#SetFontSize() ");fflush(cq->log);
 #endif
-WORD  PointSize;
+uint16_t  PointSize;
 const char *ig="!";
 
   if(WP==4) {
@@ -1943,8 +1957,8 @@ void SetFootnoteNum(TconvertedPass1 *cq, signed char WP)
 #ifdef DEBUG
   fprintf(cq->log,"\n#SetFootnoteNum() ");fflush(cq->log);
 #endif
-  WORD OldFootnoteNum,CurFootnoteNum;
-  BYTE Flag,NumID;
+  uint16_t OldFootnoteNum,CurFootnoteNum;
+  uint8_t Flag,NumID;
 
 
   switch(WP)
@@ -1980,7 +1994,7 @@ void SetPgNum(TconvertedPass1 *cq, unsigned char WP)
 #ifdef DEBUG
   fprintf(cq->log,"\n#SetPgNum() ");fflush(cq->log);
 #endif
-  WORD OldPgNum,CurPgNum;
+  uint16_t OldPgNum,CurPgNum;
 
   switch(WP)
     {
@@ -2113,16 +2127,16 @@ void Suppress(TconvertedPass1 *cq, char WP)
 #ifdef DEBUG
   fprintf(cq->log,"\n#Suppress() ");fflush(cq->log);
 #endif
-  BYTE SupType;
-  BYTE HA,HB,FA,FB,ForceNum;
+  uint8_t SupType;
+  uint8_t HA,HB,FA,FB,ForceNum;
   const char *suppress="!";
 
   if(WP==3)
   {
     fseek(cq->wpd,2l,SEEK_CUR);
-    WORD SupTypeW;
+    uint16_t SupTypeW;
     RdWORD_HiEnd(&SupTypeW, cq->wpd);
-    SupType = (BYTE)SupTypeW;
+    SupType = (uint8_t)SupTypeW;
   }
   else
   {
@@ -2170,7 +2184,7 @@ void Tab(TconvertedPass1 *cq, char WP)
   fprintf(cq->log,"\n#Tab() ");fflush(cq->log);
 #endif
 int j;
-WORD wpu;
+uint16_t wpu;
 int tabnum, new_tabs, FORLIM;
 const char *TabType="";
 
