@@ -354,7 +354,7 @@ int TconvertedPass1_602::Convert_first_pass(void)
 #ifdef DEBUG
   fprintf(log,"\n#Convert_pass1_602() ");fflush(log);
 #endif
-DWORD fsize;
+uint32_t fsize;
 
   if(Verbosing >= 1)
      printf(_("\n>>>T602toLaTeX<<< Conversion program: From T602 to LaTeX Version %s\n"
