@@ -1561,7 +1561,7 @@ void TconvertedPass1_WP6::Footnote6(uint32_t & NewPos)
     {
     envir = '^';		//Ignore enviroments Before
     NewLine(this);
-    char_on_line = -1;
+    char_on_line = JUNK_CHARS;
     }
   envir = BkEnvir;
 
@@ -1625,7 +1625,7 @@ void TconvertedPass1_WP6::Header_Footer6(void)
 #endif
  uint8_t occurance,flags,PIDS;
  attribute OldAttr;
- unsigned char OldFlag,OldEnvir;
+ unsigned char OldFlag, OldEnvir, OldFont;
  uint32_t BlockOffset,BlockSize,end_of_code;
  uint16_t ResourceNo,TextBlocks;
  Resource Res;
@@ -1672,6 +1672,7 @@ void TconvertedPass1_WP6::Header_Footer6(void)
 
   OldFlag = flag;
   OldEnvir= envir;
+  OldFont = Font;
 
   Close_All_Attr(attr,strip);
   OldAttr=attr;			/* Backup all attributes */
@@ -1729,6 +1730,7 @@ void TconvertedPass1_WP6::Header_Footer6(void)
   attr = OldAttr;	// Restore backuped attributes
   flag = OldFlag;
   envir = OldEnvir;
+  Font = OldFont;
   char_on_line = FIRST_CHAR_MINIPAGE;	// stronger false;
   recursion--;
 
