@@ -17,13 +17,13 @@
 #include"wp2latex.h"
 #include"pass1xml.h"
 #include "cp_lib/cptran.h"
-#include"images/raster.h"
+#include"images/image.h"
 
 
 int SavePictureEPS(const char *Name,const Image &Img); //froom ras_img.cc
 
 
-#define AbiwordVersion "0.10"
+#define AbiwordVersion "0.11"
 
 
 /*Register translators here*/
@@ -314,7 +314,7 @@ void TconvertedPass1_Abi::ProcessDataAbi(void)
 #endif
 unsigned char OldFlag;
 FILE *f;
-DWORD Data=0;
+uint32_t Data=0;
 char data64;
 char cnt;
 string filename;
@@ -363,10 +363,10 @@ string filename;
 
       switch(cnt)
         {
-        case 0: Data = (DWORD)data64<<18; cnt=1; break;
-        case 1: Data |= (DWORD)data64<<12;cnt=2; break;
-        case 2: Data |= (DWORD)data64<<6; cnt=3; break;
-        case 3: Data |= (DWORD)data64;
+        case 0: Data = (uint32_t)data64<<18; cnt=1; break;
+        case 1: Data |= (uint32_t)data64<<12;cnt=2; break;
+        case 2: Data |= (uint32_t)data64<<6; cnt=3; break;
+        case 3: Data |= (uint32_t)data64;
 	        cnt=0;
                 if(f) {
 	 	      fputc(Data>>16,f);
@@ -397,7 +397,7 @@ string filename;
 
     Image Img;
     Img = LoadPicture(filename());
-    if(Img.Raster!=NULL)
+    if(!Img.isEmpty())
       {
       filename = MergePaths(OutputDir,RelativeFigDir)+CutFileName(filename)+".eps";
       if(SavePictureEPS(filename(),Img)<0)
@@ -586,7 +586,7 @@ void TconvertedPass1_Abi::ProcessKeyABI(void)
 #endif
 string TAG;
 const char *tag = NULL;
-BYTE by, subby;
+uint8_t by, subby;
 
  *ObjType = 0;
  if(TAG.isEmpty()) ReadXMLTag();
@@ -734,7 +734,7 @@ int TconvertedPass1_Abi::Convert_first_pass(void)
 #ifdef DEBUG
   fprintf(log,"\n#TconvertedPass1_Abi::Convert_first_pass() ");fflush(log);
 #endif
-DWORD fsize;
+uint32_t fsize;
 
   if(Verbosing >= 1)
      printf(_("\n>>>Abiword2LaTeX<<< Conversion module: From AbiWord to LaTeX Version %s\n"
