@@ -188,7 +188,7 @@ void TconvertedPass1_Docbook::ProcessKey(void)
 #endif
 string loc_TAG;
 const char *tag;
-BYTE loc_by, loc_subby;
+uint8_t loc_by, loc_subby;
 int i;
 
  *ObjType = 0;
@@ -329,7 +329,7 @@ int TconvertedPass1_Docbook::Convert_first_pass(void)
 #ifdef DEBUG
   fprintf(log,"\n#TconvertedPass1_Docbook::Convert_first_pass() ");fflush(log);
 #endif
-DWORD fsize;
+uint32_t fsize;
 
   if(Verbosing >= 1)
      printf(_("\n>>>Docbook2LaTeX<<< Conversion program: From Docbook to LaTeX Version %s\n"
