@@ -26,7 +26,7 @@
 
 list HTMLChars(Table_html,sizeof(Table_html)/sizeof(char *));
 
-#define HTMLVersion "0.29"
+#define HTMLVersion "0.30"
 
 
 /** Base class for HTML document conversion. */
@@ -43,6 +43,7 @@ public:
 
 protected:
     void ImageHTML(void);
+    void ImageSVG(void);
     void IndentHTML(void);
     void ItemizeHTML(void);
     void LanguageHTML(const char *LangStr);
@@ -83,6 +84,7 @@ typedef enum
   TAG_xTITLE =	148,
   TAG_STYLE =   149,
   TAG_DIRECTION=150,
+  TAG_SVG =     151,
 
   TAG_HSPACE =  200,
   TAG_EXT_CHR = 201,
@@ -126,6 +128,7 @@ TagStruct OpenTags[] =
   {"STYLE",  TAG_STYLE, 0},	//STYLE
   {"SUB",    TAG_ATTR, 6},	//ATTR on subscript
   {"SUP",    TAG_ATTR, 5},	//ATTR on superscript
+  {"SVG",    TAG_SVG, 0},	//SVG Image
   {"TABLE",  TAG_TABLE, 0},	//Start of the table
   {"TD",     TAG_TABLE, 4},	//Start of cell
   {"TH",     TAG_TABLE, 6},	//Start of head cell
@@ -161,6 +164,7 @@ TagStruct CloseTags[] =
   {"STYLE",  TAG_STYLE, 1},	//STYLE
   {"SUB",    TAG_xATTR,  6},	//ATTR off subscript
   {"SUP",    TAG_xATTR,  5},	//ATTR off superscript
+  {"SVG",    TAG_SVG,  1},
   {"TABLE",  TAG_TABLE,  1},	//End of Table
   {"TD",     TAG_TABLE,  5},	//End of cell
   {"TH",     TAG_TABLE,  7},	//End of head cell
@@ -172,85 +176,6 @@ TagStruct CloseTags[] =
 };
 
 
-typedef struct
-{
-  const char* MimeType;
-  int TypeLen;
-  const char *ImageExt;
-} TMimeItem;
-
-// See: https://developer.mozilla.org/en-US/docs/Web/HTTP/Basics_of_HTTP/MIME_types/Complete_list_of_MIME_types
-const TMimeItem MimeList[] =
-{
-  {"data:image/bmp;base64", 21, ".bmp"},
-  {"data:image/gif;base64", 21, ".gif"},
-  {"data:image/jpg;base64", 21, ".jpg"},
-  {"data:image/jpeg;base64",22, ".jpg"},
-  {"data:image/png;base64", 21, ".png"},
-  {"data:image/svg+xml;base64", 25, ".svg"},
-  {"data:image/tiff;base64",22, ".tif"},
-  {"data:image/tif;base64", 21, ".tif"}
-};
-
-
-static inline bool is_base64(BYTE c) 
-{
- return (isalnum(c) || (c == '+') || (c == '/'));
-}
-
-
-// static const char *base64_chars = 
-//             "ABCDEFGHIJKLMNOPQRSTUVWXYZ"
-//             "abcdefghijklmnopqrstuvwxyz"
-//             "0123456789+/";
-
-static inline BYTE FindBase64(char ch)
-{
-  if(ch>='A' && ch<='Z') return ch - 'A';
-  if(ch>='a' && ch<='z') return ch - 'a' + 'Z'-'A'+1;
-  if(ch>='0' && ch<='9') return ch - '0' + 2*('Z'-'A')+2;
-  if(ch=='+') return 2*('Z'-'A')+2 + 10;  
-  if(ch=='/') return 2*('Z'-'A')+2 + 11;
-return 0xFF;
-}
-
-
-void base64_decode(const char *encoded_string, FILE *FOut) 
-{
-int in_len = strlen(encoded_string);
-int i = 0;
-int in_ = 0;
-BYTE char_array_4[4], char_array_3[3];
-
-  while(in_len-- && (encoded_string[in_]!='=') && is_base64(encoded_string[in_])) 
-    {
-    char_array_4[i++] = FindBase64(encoded_string[in_++]);
-
-    if(i==4) 
-      {
-      char_array_3[0] = (char_array_4[0] << 2) + ((char_array_4[1] & 0x30) >> 4);
-      char_array_3[1] = ((char_array_4[1] & 0xf) << 4) + ((char_array_4[2] & 0x3c) >> 2);
-      char_array_3[2] = ((char_array_4[2] & 0x3) << 6) + char_array_4[3];
-
-      fwrite(char_array_3,1,3,FOut);      
-      i = 0;
-      }
-    }
-
-  if(i) 
-  {
-    memset(char_array_4+i, FindBase64(0), 4-i);    
-
-    char_array_3[0] = (char_array_4[0] << 2) + ((char_array_4[1] & 0x30) >> 4);
-    char_array_3[1] = ((char_array_4[1] & 0xf) << 4) + ((char_array_4[2] & 0x3c) >> 2);
-    char_array_3[2] = ((char_array_4[2] & 0x3) << 6) + char_array_4[3];
-    
-    fwrite(&char_array_3, 1, i-1, FOut);
-  }
-
-  return;
-}
-
 
 #define PAPER_SIZE	210.0f
 #define PagePixels 800.0f
@@ -285,7 +210,7 @@ string NewFileName;
           FileName += MimeList[i].TypeLen + 1;
           break;
           }
-        }      
+        }
 
       if(NewFileName.length()>0)
         {      
@@ -324,8 +249,8 @@ string NewFileName;
 		 break;					//normal
 	  case '%':Box.HorizontalPos=4;
 		 if(Box.Width<=0) Box.HorizontalPos=3;
-		 break;				        //percentage
-	  default:break;			        //nothing
+		 break;					//percentage
+	  default:break;				//nothing
 	  }
 	}
   if(FileName==NULL) FileName="dummy";
@@ -341,6 +266,83 @@ return;
 }
 
 
+void TconvertedPass1_HTML::ImageSVG(void)
+{
+#ifdef DEBUG
+  fprintf(log,"\n#ImageSVG() ");fflush(log);
+#endif
+TBox Box;
+const char *FileName=NULL;
+string NewFileName;
+unsigned char OldFlag;
+long SVGStart = ActualPos;
+long SVGEnd;
+char OldEnvir;
+
+  OldFlag = flag;
+  OldEnvir = envir;
+  flag = Nothing;
+  recursion++;
+
+  ReadXMLTag();
+  while(!feof(wpd))
+  {
+/*	if(by==0 && (subby==10 || subby==13))
+		{
+		subby=' ';	// remove \n from cell text
+		} */
+    ProcessKeyHTML();
+    if(by==TAG_SVG)
+    {
+      if(subby==1) break; /*End of SVG*/
+    }
+
+    ReadXMLTag();
+  }
+  flag = OldFlag;
+  envir = OldEnvir;
+  recursion--;
+  SVGEnd = ftell(wpd);
+
+  initBox(Box);
+  Box.Width = -1; 		// Undefined, use default 100mm
+  Box.Image_type=0;		// Image on disk
+  Box.AnchorType = 0; 		// 0-Paragraph, 1-Page, 2-Character
+  Box.HorizontalPos=2;		// 0-Left, 1-Right, 2-Center, 3-Full
+
+  NewFileName = MergePaths(OutputDir,RelativeFigDir) + GetSomeImgName(".svg");
+  if(NewFileName.length()>0)
+  {
+    FILE *F = fopen(NewFileName(),"wb");
+    if(F)
+    {
+      fseek(wpd,SVGStart,SEEK_SET);
+      CopyFile(F, wpd, SVGEnd-SVGStart);
+
+      fclose(F);
+    }
+    else
+    {
+      if(err != NULL)
+      {
+        perc.Hide();
+        fprintf(err,_("\nError: Cannot create image file: \"%s\"."),NewFileName());
+      }
+      NewFileName.erase();
+    }
+  }
+
+  if(NewFileName.isEmpty()) NewFileName="dummy";
+
+  ImageWP(this, NewFileName(), Box);
+
+  if(NewFileName.length()>0 && SaveWPG<0)
+    {
+    unlink(NewFileName());
+    }
+}
+
+
 void TconvertedPass1_HTML::IndentHTML(void)
 {
 #ifdef DEBUG
@@ -666,7 +668,7 @@ void TconvertedPass1_HTML::ProcessKeyHTML(void)
 #endif
  string TAG;
  const char *tag = NULL;
- BYTE by, subby;
+ uint8_t by, subby;
  int i;
 
  *ObjType = 0;
@@ -694,7 +696,7 @@ void TconvertedPass1_HTML::ProcessKeyHTML(void)
                           if(by==';')
                             {TAG="\\textrm{;}";by=XML_extchar;break;}
                         }
-                        if(Font==FONT_HEBREW || Font==FONT_CYRILLIC)
+                        if(Font==FONT_HEBREW || Font==FONT_CYRILLIC || Font==FONT_GEORGIA)
                         {
                           RequiredFont = FONT_NORMAL;
                         }
@@ -810,7 +812,7 @@ void TconvertedPass1_HTML::ProcessKeyHTML(void)
 	case TAG_SCRIPT:ScriptXML();		  break;
 	case TAG_HR:	HLine(this,-16);	  break;
 	case TAG_DD:	IndentHTML();	break;
-        case TAG_DIRECTION: strcpy(ObjType, "!Direction"); break;
+	case TAG_DIRECTION: strcpy(ObjType, "!Direction"); break;
 	case TAG_xINDENT:End_of_indent(this);	break;
 	case TAG_IMG:	ImageHTML();		break;
 	case TAG_TABLE: switch(subby)
@@ -841,9 +843,10 @@ void TconvertedPass1_HTML::ProcessKeyHTML(void)
 		break;
 		}
 
-        case TAG_TITLE: TitleHTML();	break;
+	case TAG_SVG:   ImageSVG(); break;
+	case TAG_TITLE: TitleHTML(); break;
 
-        case TAG_STYLE: StyleHTML();	break;
+	case TAG_STYLE: StyleHTML(); break;
 
 	case TAG_HSPACE:fputc('~', strip); strcpy(ObjType, " ");
 		 break;
@@ -893,7 +896,7 @@ int TconvertedPass1_HTML::Convert_first_pass(void)
 #ifdef DEBUG
   fprintf(log,"\n#Convert_pass1_HTML() ");fflush(log);
 #endif
-DWORD fsize;
+uint32_t fsize;
 
   if(Verbosing >= 1)
      printf(_("\n>>>HTML2LaTeX<<< Conversion program: From HTML to LaTeX Version %s\n"
