@@ -690,11 +690,11 @@ string arg[4];
 	StrB=cq->Formula;	cq->Formula.erase();
 	OldBy=cq->by;
 
-	str2=strstr(TemplateStr,"0");
+	str2 = strchr(TemplateStr,'0');
 	while(str2!=NULL && str2>TemplateStr)
 		{
 		if(*(str2-1)!='@') break;  //test whether @ preceeds 0
-		str2=strstr(str2+1,"0");
+		str2 = strchr(str2+1,'0');
 		}
 	if(str2!=NULL)
 		{
@@ -771,11 +771,11 @@ char Num[2]="0";
 	fprintf(cq->log,"\n%*s[TMPL %d,%u]",cq->recursion * 2,"",Selector,Variation);
   cq->recursion++;
 
-  str2=strstr(TemplateStr,"0");
+  str2 = strchr(TemplateStr,'0');
   while(str2>TemplateStr)
 	{
 	if(*(str2-1)=='@')
-		str2=strstr(str2+1,"0");
+		str2 = strchr(str2+1,'0');
 	}
   if(str2!=NULL)
 	{
