@@ -6,7 +6,7 @@
  *              It could be optionally not compiled with WP2LaTeX package.    *
  * licency:     GPL		                                              *
  ******************************************************************************/
-#define RTF_Ver "0.15"
+#define RTF_Ver "0.16"
 //TODO: Dodelat znak ? - maze mezeru pred sebou
 //      Autodetekce \section podle xref _TOCxxxxxx
 
@@ -78,7 +78,7 @@ typedef struct save	// property save structure
 {
     struct save *pNext;	// next save
 
-    attribute CharA;    // CHaracter Properties
+    attribute CharA;	// CHaracter Properties
     PAP pap;		// PAragraph Properties
     SEP sep;		// SEction Properties
     DOP dop;		// DOcument Properties
@@ -173,13 +173,21 @@ public:CpTranslator *Unicode;
 
        list FontTable;
        virtual int Convert_first_pass();
+
+       int ecApplyPropChange(int isym, int val);
+       int ecTranslateKeyword(const char *szKeyword, int param, bool fParam);
+       int ecParseChar(int ch);
+       int ecChangeDest(IDEST idest);
+       int ecParseSpecialKeyword(IPFN ipfn);
+       void MakeLabelRTF(void);
+       void SpecialObject(void);
+       void fldinst(void);
+       int ProcessKeyRTF(void);
        };
 TconvertedPass1 *Factory_RTF(void) {return new TconvertedPass1_RTF;}
 FFormatTranslator FormatRTF("RTF",Factory_RTF);
 
 
-static int ProcessKeyRTF(TconvertedPass1_RTF *cq);
-
 // RTF parser table: Keyword descriptions
 SYM rgsymRtf[] = {
 //  keyword     dflt      sizearg   kwd fPassDflt                  idx
@@ -409,25 +417,25 @@ static int ecParseSpecialProperty(TconvertedPass1_RTF *cq,IPROP iprop, int val)
 
 
 /// Set the property identified by _iprop_ to the value _val_.
-static int ecApplyPropChange(TconvertedPass1_RTF *cq, int isym, int val)
+int TconvertedPass1_RTF::ecApplyPropChange(int isym, int val)
 {
 #ifdef DEBUG
-  fprintf(cq->log,"\n#ecApplyPropChange() ");fflush(cq->log);
+  fprintf(log,"\n#TconvertedPass1_RTF::ecApplyPropChange() ");fflush(log);
 #endif
 char *pb;
 
-  if (cq->rds >= rdsSkip)                 // If we're skipping text,
+  if (rds >= rdsSkip)                 // If we're skipping text,
 	return ecOK;                    // don't do anything.
 
   switch (rgsymRtf[isym].F.PropScope & 3)
     {
-    case propDop: pb = (char *)&cq->dop;
+    case propDop: pb = (char *)&dop;
 		  break;
-    case propSep: pb = (char *)&cq->sep;
+    case propSep: pb = (char *)&sep;
 		  break;
-    case propPap: pb = (char *)&cq->pap;
+    case propPap: pb = (char *)&pap;
 		  break;
-    case propChp: pb = (char *)&cq->chp;
+    case propChp: pb = (char *)&chp;
 		  break;
     default: if ((rgsymRtf[isym].F.PropSize&3) != actnSpec) return ecBadTable;
 	     break;
@@ -447,17 +455,17 @@ char *pb;
 
 // Change to the destination specified by idest.
 // There's usually more to do here than this...
-static int ecChangeDest(TconvertedPass1_RTF *cq, IDEST idest)
+int TconvertedPass1_RTF::ecChangeDest(IDEST idest)
 {
 #ifdef DEBUG
-  fprintf(cq->log,"\n#ecChangeDest() ");fflush(cq->log);
+  fprintf(log,"\n#TconvertedPass1_RTF::ecChangeDest() ");fflush(log);
 #endif
-  if (cq->rds >= rdsSkip)             // if we're skipping text,
+  if (rds >= rdsSkip)             // if we're skipping text,
         return ecOK;                // don't do anything
 
   switch (idest)
     {
-    default:cq->rds = rdsSkip;              // when in doubt, skip it...
+    default:rds = rdsSkip;              // when in doubt, skip it...
 	    break;
     }
   return ecOK;
@@ -465,17 +473,17 @@ static int ecChangeDest(TconvertedPass1_RTF *cq, IDEST idest)
 
 
 /// Route the character to the appropriate destination stream.
-static int ecParseChar(TconvertedPass1_RTF *cq, int ch)
+int TconvertedPass1_RTF::ecParseChar(int ch)
 {
 #ifdef DEBUG
-  fprintf(cq->log,"\n#ecParseChar(%c) ",ch);fflush(cq->log);
+  fprintf(log,"\n#ecParseChar(%c) ",ch);fflush(log);
 #endif
 
-  if (cq->ris == risBin && --cq->cbBin <= 0)
-	       cq->ris = risNorm;
-  if(cq->flag==Nothing) return(ecOK);	//do not output a character if nothing is required
+  if (ris == risBin && --cbBin <= 0)
+	       ris = risNorm;
+  if(flag==Nothing) return(ecOK);	//do not output a character if nothing is required
 
-  switch (cq->rds)
+  switch (rds)
     {
     case rdsShpInst:
     case rdsSkip: return ecOK;  // Toss this character.
@@ -483,15 +491,28 @@ static int ecParseChar(TconvertedPass1_RTF *cq, int ch)
 		   {
 		   case  9:return(ecOK);// ecPrintChar(cq,'\t'); - ignore tabulator
 		   case 10:
-		   case 13:if(cq->char_on_line==CHAR_PRESENT) NewLine(cq);
+		   case 13:if(char_on_line==CHAR_PRESENT) NewLine(this);
 			   break;
 		   default:if(ch==0) return(ecOK); // unfortunately, we don't do a whole lot here as far as layout goes...
-			   if(memcmp(&cq->NewRGB,&cq->RGB,sizeof(RGBQuad)))
+			   if(memcmp(&NewRGB,&RGB,sizeof(RGBQuad)))
 				{
-				cq->RGB=cq->NewRGB;
-				Color(cq,0,&cq->RGB);
+				RGB=NewRGB;
+				Color(this,0,&RGB);
 				}
-			   CharacterStr(cq,Ext_chr_str(ch,cq,cq->ConvertCpg));
+			   {
+			   const char * const CharCode = Ext_chr_str(ch,this,ConvertCpg);
+			   CharacterStr(this,CharCode);
+			   if(log)
+			   {
+			     if(ch>128 && CharCode!=NULL)
+			     {
+			       if(!strcmp(CharCode," -?- "))
+			         fprintf(log,"Chr(%Xh)", ch);
+			       else
+			         fprintf(log,"(%s)", CharCode);
+                             }
+			   }
+			   }
 			   return(ecOK);
 		   }
     default:      // Handle other destinations.
@@ -502,24 +523,24 @@ return ecOK;
 
 
 /// Evaluate an RTF control that needs special processing.
-static int ecParseSpecialKeyword(TconvertedPass1_RTF *cq,IPFN ipfn)
+int TconvertedPass1_RTF::ecParseSpecialKeyword(IPFN ipfn)
 {
 #ifdef DEBUG
-  fprintf(cq->log,"\n#ecParseSpecialKeyword() ");fflush(cq->log);
+  fprintf(log,"\n#ecParseSpecialKeyword() ");fflush(log);
 #endif
-    if (cq->rds >= rdsSkip && ipfn != ipfnBin)  // if we're skipping, and it's not
+    if (rds >= rdsSkip && ipfn != ipfnBin)  // if we're skipping, and it's not
         return ecOK;                        // the \bin keyword, ignore it.
     switch (ipfn)
     {
     case ipfnBin:
-	  cq->ris = risBin;
-	  cq->cbBin = cq->lParam;
+	  ris = risBin;
+	  cbBin = lParam;
 	  break;
     case ipfnSkipDest:
-	  cq->fSkipDestIfUnk = true;
+	  fSkipDestIfUnk = true;
 	  break;
     case ipfnHex:
-	  cq->ris = risHex;
+	  ris = risHex;
 	  break;
     default:return ecBadTable;
     }
@@ -527,7 +548,6 @@ static int ecParseSpecialKeyword(TconvertedPass1_RTF *cq,IPFN ipfn)
 }
 
 
-
 // Step 3.
 // Search rgsymRtf for szKeyword and evaluate it appropriately.
 //
@@ -536,10 +556,10 @@ static int ecParseSpecialKeyword(TconvertedPass1_RTF *cq,IPFN ipfn)
 // param:       The parameter of the RTF control.
 // fParam:      true if the control had a parameter; (i.e., if param is valid)
 //              false if it did not.
-static int ecTranslateKeyword(TconvertedPass1_RTF *cq,const char *szKeyword, int param, bool fParam)
+int TconvertedPass1_RTF::ecTranslateKeyword(const char *szKeyword, int param, bool fParam)
 {
 #ifdef DEBUG
-  fprintf(cq->log,"\n#ecTranslateKeyword() ");fflush(cq->log);
+  fprintf(log,"\n#TconvertedPass1_RTF::ecTranslateKeyword() ");fflush(log);
 #endif
 int isym;
 
@@ -551,30 +571,30 @@ int isym;
   if (isym == isymMax)            // control word not found
 	{
 	UnknownObjects++;
-	if (cq->fSkipDestIfUnk)         // if this is a new destination
+	if(fSkipDestIfUnk)         // if this is a new destination
 	    {
-	    cq->rds = rdsSkip;          // skip the destination
+	    rds = rdsSkip;          // skip the destination
 	    }
 				    // else just discard it
-	cq->fSkipDestIfUnk = false;
+	fSkipDestIfUnk = false;
 	return ecOK;
 	}
 
 // found it!  use kwd and idx to determine what to do with it.
 
-  cq->fSkipDestIfUnk = false;
+  fSkipDestIfUnk = false;
   switch (rgsymRtf[isym].F.Kwd & 3)
     {
     case kwdProp:
 	if (rgsymRtf[isym].F.ForceArg || !fParam)
 	    param = rgsymRtf[isym].dflt;
-	return ecApplyPropChange(cq,isym,param);
+	return ecApplyPropChange(isym,param);
     case kwdChar:
-	return ecParseChar(cq,rgsymRtf[isym].idx);
+	return ecParseChar(rgsymRtf[isym].idx);
     case kwdDest:
-	return ecChangeDest(cq,(IDEST)rgsymRtf[isym].idx);
+	return ecChangeDest((IDEST)rgsymRtf[isym].idx);
     case kwdSpec:
-	return ecParseSpecialKeyword(cq,(IPFN)rgsymRtf[isym].idx);
+	return ecParseSpecialKeyword((IPFN)rgsymRtf[isym].idx);
     }
 
   return ecBadTable;
@@ -923,10 +943,10 @@ FINISH:
 }
 
 
-static void fldinst(TconvertedPass1_RTF *cq)
+void TconvertedPass1_RTF::fldinst(void)
 {
 #ifdef DEBUG
-  fprintf(cq->log,"\n#fldinst() ");fflush(cq->log);
+  fprintf(log,"\n#fldinst() ");fflush(log);
 #endif
 string Str;
 int state;
@@ -937,7 +957,7 @@ int CurlyBraces=0;
 
 state=0;
 do {
-   Str = RTFReadFirstWord(cq->wpd,&c);
+   Str = RTFReadFirstWord(wpd,&c);
    switch(state)
 	{
 	case 0:if(Str=="SYMBOL") state=1;
@@ -952,19 +972,19 @@ do {
 	       Str.ToLower();
 	       CpTrn = GetTranslator(string(Str+"TOinternal"));
 	       if(CpTrn==NULL) {state=0;break;}  //This should be reviewed!!!!!!
-	       CharacterStr(cq,Ext_chr_str(pos,cq,CpTrn));
+	       CharacterStr(this,Ext_chr_str(pos,this,CpTrn));
 	       state=0;
 	       break;
 
 	case 10:if(!Str.isEmpty())
 		  {
-		  fprintf(cq->strip, " \\pageref{%s}",Str());
+		  fprintf(strip, " \\pageref{%s}",Str());
 		  state=0;
 		  }
 		break;
 	case 20:if(!Str.isEmpty())
 		  {
-		  fprintf(cq->strip, " \\ref{%s}",Str());
+		  fprintf(strip, " \\ref{%s}",Str());
 		  state=0;
 		  }
 		break;
@@ -973,7 +993,7 @@ do {
    if(c=='{')
 	{
 	CurlyBraces++;
-	c=fgetc(cq->wpd);
+	c=fgetc(wpd);
 	Str=c;
 	continue;
 	}
@@ -982,7 +1002,7 @@ do {
 	state=0;
 	if(CurlyBraces-->0)
 	   {
-	   c=fgetc(cq->wpd);
+	   c=fgetc(wpd);
 	   Str=c;
 	   continue;
 	   }
@@ -1048,7 +1068,7 @@ static void FootnoteRTF(TconvertedPass1_RTF *cq)
 	     case 0xd:putc(' ', cq->strip);
 		      break;
 
-	     default: ProcessKeyRTF(cq);
+	     default: cq->ProcessKeyRTF();
 		      break;
 	     }
 
@@ -1115,7 +1135,7 @@ static void FontTableRTF(TconvertedPass1_RTF *cq)
 		    case 200: CurlyBaraceStack++; break;
 		    case 201: CurlyBaraceStack--; break;
 		    }
-		  ProcessKeyRTF(cq);
+		  cq->ProcessKeyRTF();
 		  }
 		cq->recursion--;
 		s.trim();
@@ -1126,7 +1146,7 @@ static void FontTableRTF(TconvertedPass1_RTF *cq)
 		}
 	   }
 
-	ProcessKeyRTF(cq);
+	cq->ProcessKeyRTF();
 	}
   cq->ActualPos = ftell(cq->wpd);
 
@@ -1145,17 +1165,20 @@ static void HeaderFooterRTF(TconvertedPass1_RTF *cq, unsigned char HFtype)
 #ifdef DEBUG
   fprintf(cq->log,"\n#HeaderFooterRTF(%d) ",(int)HFtype); fflush(cq->log);
 #endif
-  unsigned char OldFlag,OldEnvir;
+  unsigned char OldFlag, OldEnvir, OldFont;
   attribute OldAttr;
   int CurlyBaraceStack;
 
-  CurlyBaraceStack=1;
+  CurlyBaraceStack = 1;
   OldFlag = cq->flag;
+
+  Close_All_Attr(cq->attr, cq->strip);
   OldAttr = cq->attr;
-  OldEnvir= cq->envir;
+  OldEnvir = cq->envir;
+  OldFont = cq->Font;
+  cq->attr.InitAttr();		//Turn all attributes in the header/footer off
 
 // Start a conversion of a Header or Footer
-  cq->attr.InitAttr();		//Turn all attributes in the header/footer off
   cq->recursion++;
 
   cq->line_term = 's';    	//Soft return
@@ -1169,13 +1192,17 @@ static void HeaderFooterRTF(TconvertedPass1_RTF *cq, unsigned char HFtype)
       NewLine(cq);
       }
 
+  if(OldEnvir=='L' || OldEnvir=='B') // || BkEnvir=='i')
+  {
+    cq->envir = '!';		//Ignore enviroments after header/footer
+    NewLine(cq);
+    cq->envir = ' ';
+  }
+  //cq->envir = ' ';
+
 //	             (HFtype2 & 3) <= 1 ? "\\headtext":"\\foottext"
   InitHeaderFooter(cq,HFtype & 3,HFtype >> 2);
 
-  cq->envir='!';		//Ignore enviroments after header/footer
-  NewLine(cq);
-
-  cq->envir = ' ';
   cq->flag = HeaderText;
   cq->char_on_line = FIRST_CHAR_MINIPAGE;
   while (!feof(cq->wpd) && CurlyBaraceStack > 0)
@@ -1203,7 +1230,7 @@ static void HeaderFooterRTF(TconvertedPass1_RTF *cq, unsigned char HFtype)
 	     case 0xd:putc(' ', cq->strip);
 		      break;
 
-	     default: ProcessKeyRTF(cq);
+	     default: cq->ProcessKeyRTF();
 		      break;
 	     }
 
@@ -1211,23 +1238,34 @@ static void HeaderFooterRTF(TconvertedPass1_RTF *cq, unsigned char HFtype)
   cq->ActualPos = ftell(cq->wpd);
 
   Close_All_Attr(cq->attr,cq->strip);
-  if(cq->char_on_line==CHAR_PRESENT)
+
+  if(cq->envir != ' ')
      {
      cq->line_term = 's';    	//Soft return
      NewLine(cq);
      }
   putc('}', cq->strip);
 
-  cq->line_term = 's';    	//Soft return
-  cq->envir='^';		//Ignore enviroments after header/footer
-  NewLine(cq);
+  if(cq->envir != ' ')
+    {
+    cq->envir = ' ';
+    NewLine(cq);
+    }
+  if(OldEnvir=='L' || OldEnvir=='B') // || BkEnvir=='i')
+  {
+    cq->line_term = 's';    	//Soft return
+    cq->envir = '^';		//Ignore enviroments Before
+    NewLine(cq);
+    cq->char_on_line = JUNK_CHARS;
+  }
 
   cq->recursion--;
 
   cq->attr = OldAttr;
   cq->flag = OldFlag;
   cq->envir= OldEnvir;
-  cq->char_on_line = FIRST_CHAR_MINIPAGE;
+  cq->Font = OldFont;
+  cq->char_on_line = FIRST_CHAR_MINIPAGE;	// stronger false;
 
   strcpy(cq->ObjType, ((HFtype & 3) <= 1)?"Header":"Footer");
 }
@@ -1281,7 +1319,7 @@ static void IndexRTF(TconvertedPass1_RTF *cq)
 	     case 0xd:putc(' ', cq->strip);
 		      break;
 
-	     default: ProcessKeyRTF(cq);
+	     default: cq->ProcessKeyRTF();
 		      break;
 	     }
 
@@ -1341,8 +1379,8 @@ TBox Box;
 
   while (!feof(cq->wpd))
 	{
-	cq->subby=RTFLoadKeyword(cq);
-	ProcessKeyRTF(cq);
+	cq->subby = RTFLoadKeyword(cq);
+	cq->ProcessKeyRTF();
 
 //	if(cq->subby>=202 && cq->subby<=204) printf("%s\n",cq->Keyword() );
 
@@ -1377,27 +1415,27 @@ TBox Box;
 }
 
 
-static void MakeLabelRTF(TconvertedPass1_RTF *cq)
+void TconvertedPass1_RTF::MakeLabelRTF(void)
 {
 #ifdef DEBUG
-  fprintf(cq->log,"\n#MakeLabelRTF() ");fflush(cq->log);
+  fprintf(log,"\n#TconvertedPass1_RTF::MakeLabelRTF() ");fflush(log);
 #endif
   string LBL_Text;
   char c;
 
-  LBL_Text=RTFReadFirstWord(cq->wpd,&c);
+  LBL_Text=RTFReadFirstWord(wpd,&c);
   if(c!='}') {
-	     ecParseSpecialKeyword(cq,ipfnSkipDest);
-	     cq->rds=rdsSkip;
+	     ecParseSpecialKeyword(ipfnSkipDest);
+	     rds=rdsSkip;
 	     }
-	else c=fgetc(cq->wpd); 		//read the closing curly brace
+	else c=fgetc(wpd); 		//read the closing curly brace
   if(!LBL_Text.isEmpty())
     {
-    fprintf(cq->strip, "%s\\label{%s}",cq->char_on_line>0?" ":"",LBL_Text());
-    if(cq->char_on_line == false)
-		cq->char_on_line = -1;
+    fprintf(strip, "%s\\label{%s}",char_on_line>0?" ":"",LBL_Text());
+    if(char_on_line == false)
+		char_on_line = -1;
     }
-  strcpy(cq->ObjType, "Label");
+  strcpy(ObjType, "Label");
 }
 
 
@@ -1446,46 +1484,46 @@ int ch;
 }
 
 
-/*special object is the stream marked with \*\xxx command*/
-static void SpecialObject(TconvertedPass1_RTF *cq)
+/** special object is the stream marked with \*\xxx command. */
+void TconvertedPass1_RTF::SpecialObject(void)
 {
 #ifdef DEBUG
-  fprintf(cq->log,"\n#SpecialObject() ");fflush(cq->log);
+  fprintf(log,"\n#TconvertedPass1_RTF::SpecialObject() ");fflush(log);
 #endif
 uint32_t FilePos;
 string ObjectName,Type;
 char c;
 
-  if (cq->rds == rdsSkip) return;
+  if (rds == rdsSkip) return;
 
-  FilePos=ftell(cq->wpd);
-  c=fgetc(cq->wpd);
-  if(c=='\\') c=fgetc(cq->wpd);
+  FilePos=ftell(wpd);
+  c=fgetc(wpd);
+  if(c=='\\') c=fgetc(wpd);
   do {
-     if(c=='\\') {ungetc(c,cq->wpd);break;}
+     if(c=='\\') {ungetc(c,wpd);break;}
      if(c=='}' || c=='{')
 	{
-	ungetc(c,cq->wpd);
-	ecParseSpecialKeyword(cq,ipfnSkipDest);
+	ungetc(c,wpd);
+	ecParseSpecialKeyword(ipfnSkipDest);
 	return;
 	}
      Type+=c;
-     c=fgetc(cq->wpd);
+     c=fgetc(wpd);
      } while(!isspace(c));
 
 
-  strncpy(cq->ObjType,Type(),sizeof(cq->ObjType));
-  cq->ObjType[sizeof(cq->ObjType)-1]=0;
+  strncpy(ObjType,Type(),sizeof(ObjType));
+  ObjType[sizeof(ObjType)-1]=0;
 
   if(Type=="bkmkstart")
 	{
-	MakeLabelRTF(cq);
+	MakeLabelRTF();
 	return;
 	}
 
   if(Type=="fldinst")
 	{
-	fldinst(cq);
+	fldinst();
 	return;
 	}
 
@@ -1497,36 +1535,36 @@ char c;
 	{
 	do {
 	   do {
-	      if(feof(cq->wpd))
+	      if(feof(wpd))
 		{
-		ecParseSpecialKeyword(cq,ipfnSkipDest);
+		ecParseSpecialKeyword(ipfnSkipDest);
 		return;
 		}
-	      c=fgetc(cq->wpd);
+	      c=fgetc(wpd);
 	      } while(isspace(c));
-	   if(c=='}' || c=='\\') {ungetc(c,cq->wpd);break;}
+	   if(c=='}' || c=='\\') {ungetc(c,wpd);break;}
 	   if(c=='{' || !isxdigit(c))
 	     {
-	     fseek(cq->wpd,FilePos,SEEK_SET);
-	     ecParseSpecialKeyword(cq,ipfnSkipDest);
+	     fseek(wpd,FilePos,SEEK_SET);
+	     ecParseSpecialKeyword(ipfnSkipDest);
 	     return;
 	     }
 	   ObjectName+=c;
 	   if(length(ObjectName)==70)	//Equation.3 needs 70 bytes
 		{			//Equation.DSMT4 needs 78 bytes
-		c=fgetc(cq->wpd);
-		ungetc(c,cq->wpd);
+		c=fgetc(wpd);
+		ungetc(c,wpd);
 		if(!isxdigit(c)) break;
 		}
 	   } while(length(ObjectName)<78);
 
-	ExtractHexObject(cq);
+	ExtractHexObject(this);
 	return;
 	}
 
   if(Type=="shpinst")
 	{
-	cq->rds=rdsShpInst;
+	rds=rdsShpInst;
 	return;
 	}
 
@@ -1535,27 +1573,27 @@ char c;
 /*
   if(Type=="objclass")
 	{
-	while(isspace(c)) c=fgetc(cq->wpd);
+	while(isspace(c)) c=fgetc(wpd);
 	do {
-	   if(c=='}' || c=='\\') {ungetc(c,cq->wpd);break;}
+	   if(c=='}' || c=='\\') {ungetc(c,wpd);break;}
 	   if(c=='{')
 	     {
-	     fseek(cq->wpd,FilePos,SEEK_SET);
+	     fseek(wpd,FilePos,SEEK_SET);
 	     ecParseSpecialKeyword(cq,ipfnSkipDest);
 	     return;
 	     }
 	   ObjectName+=c;
-	   if(feof(cq->wpd))
+	   if(feof(wpd))
 	     {
 	     ecParseSpecialKeyword(cq,ipfnSkipDest);
 	     return;
 	     }
-	   c=fgetc(cq->wpd);
+	   c=fgetc(wpd);
 	   } while(!isspace(c));
 //	asm int 3;
 	}*/
-  ecParseSpecialKeyword(cq,ipfnSkipDest);
-  cq->rds=rdsSkip;		//skip all "\*" stream because it is not known
+  ecParseSpecialKeyword(ipfnSkipDest);
+  rds=rdsSkip;		//skip all "\*" stream because it is not known
 }
 
 
@@ -1564,432 +1602,431 @@ char c;
 // Isolate RTF keywords and send them to ecParseRtfKeyword;
 // Push and pop state at the start and end of RTF groups;
 // Send text to ecParseChar for further processing.
-static int ProcessKeyRTF(TconvertedPass1_RTF *cq)
+int TconvertedPass1_RTF::ProcessKeyRTF(void)
 {
 #ifdef DEBUG
-  fprintf(cq->log,"\n#ProcessKeyRTF() ");fflush(cq->log);
+  fprintf(log,"\n#TconvertedPass1_RTF::ProcessKeyRTF() ");fflush(log);
 #endif
 int ec;
 int KeywordType;
 
-  if (cq->cGroup < 0) return ecStackUnderflow;
+  if (cGroup < 0) return ecStackUnderflow;
 
-  if(cq->by==0) KeywordType=RTFLoadKeyword(cq);
-	   else KeywordType=cq->subby;
+  if(by==0) KeywordType=RTFLoadKeyword(this);
+	   else KeywordType=subby;
 
   switch(KeywordType)
      {
      case 0:return ecOK;	 		    //EOF;
-     case 1:if((ec = ecParseChar(cq,cq->by)) != ecOK)  //Binary; if we're parsing binary data, handle it directly
+     case 1:if((ec = ecParseChar(by)) != ecOK)  //Binary; if we're parsing binary data, handle it directly
 		return ec;
 	    goto RTFnext;
-     case 2:if((ec = ecParseChar(cq,cq->by)) != ecOK)  //unknown;
+     case 2:if((ec = ecParseChar(by)) != ecOK)  //unknown;
 			return ec;
 	    break;
      case 3:return ecInvalidHex;		    //Bad Hex
      case 0xA:
-     case 0xD:if(cq->char_on_line==CHAR_PRESENT) NewLine(cq);
+     case 0xD:if(char_on_line==CHAR_PRESENT) NewLine(this);
 		      break;          // cr and lf are noise characters...    - EOL;
-     case 200:if ((ec = ecPushRtfState(cq)) != ecOK)	// {
+     case 200:if ((ec = ecPushRtfState(this)) != ecOK)	// {
 			 return ec;
 	      break;
-     case 201:if ((ec = ecPopRtfState(cq)) != ecOK)	 // }
+     case 201:if ((ec = ecPopRtfState(this)) != ecOK)	 // }
 			 return ec;
 	       break;
      case 202:				 //keyword no arg
      case 203:				 //wrong arg
-     case 204:strncpy(cq->ObjType+1,cq->Keyword,sizeof(cq->ObjType)-1);
-	      *(cq->ObjType)='\\';
+     case 204:strncpy(ObjType+1,Keyword,sizeof(ObjType)-1);
+	      *(ObjType)='\\';
 
-	     if(cq->Keyword=='*') {SpecialObject(cq);break;}
+	     if(Keyword=='*') {SpecialObject();break;}
 
-	      if(cq->Keyword=='~')
+	      if(Keyword=='~')
 		  {
-		  fputc('~', cq->strip);
+		  fputc('~', strip);
 		  break;
 		  }
-	      if(cq->Keyword=="ansi")
+	      if(Keyword=="ansi")
 		  {
-		  cq->ConvertCpg = NULL;
+		  ConvertCpg = NULL;
 		  break;
 		  }
-	      if(cq->Keyword=="ansicpg")
+	      if(Keyword=="ansicpg")
 		  {
-		  ChangeCpTranslator(cq);
+		  ChangeCpTranslator(this);
 		  break;
 		  }
-	      if(cq->Keyword=='b')
+	      if(Keyword=='b')
 		  {
-		  if(!cq->isParam) cq->lParam=1;
-		  if(cq->lParam) AttrOn(cq->attr,12);	/* Start boldface */
-			    else AttrOff(cq,12);	/* End boldface */
+		  if(!isParam) lParam=1;
+		  if(lParam) AttrOn(attr,12);	/* Start boldface */
+			    else AttrOff(this,12);	/* End boldface */
 		  break;
 		  }
-	      if(cq->Keyword=="blue")
+	      if(Keyword=="blue")
 		  {
-		  if(!cq->isParam) cq->lParam=0;
-		  cq->NewRGB.B=cq->lParam;
+		  if(!isParam) lParam=0;
+		  NewRGB.B=lParam;
 		  break;
 		  }
-	      if(cq->Keyword=="bullet")
+	      if(Keyword=="bullet")
 		  {
-		  CharacterStr(cq,Ext_chr_str(8226, cq, cq->Unicode)); break;
+		  CharacterStr(this, Ext_chr_str(8226, this, Unicode)); break;
 		  }
-	      if(cq->Keyword=="cf")
+	      if(Keyword=="cf")
 		  {
-		  if(cq->isParam)
-		    if(cq->lParam<cq->nColorTBL && cq->lParam>=1)
+		  if(isParam)
+		    if(lParam<nColorTBL && lParam>=1)
 			{
-			cq->NewRGB=cq->ColorTBL[cq->lParam-1];
+			NewRGB=ColorTBL[lParam-1];
 			}
 		  }
-	      if(cq->Keyword=="chdate")
+	      if(Keyword=="chdate")
 		  {
-		  DateCode(cq);break;
+		  DateCode(this); break;
 		  }
-	      if(cq->Keyword=="chpgn")
+	      if(Keyword=="chpgn")
 		  {
-		  PageNumber(cq);break;
+		  PageNumber(this); break;
 		  }
-	      if(cq->Keyword=="colortbl")
+	      if(Keyword=="colortbl")
 		  {
-		  ColorTable(cq);break;
+		  ColorTable(this); break;
 		  }
-	      if(cq->Keyword=="cols")
+	      if(Keyword=="cols")
 		  {
-		  if(!cq->isParam) cq->lParam=1;
-		  Column(cq,cq->lParam);
+		  if(!isParam) lParam=1;
+		  Column(this,lParam);
 		  }
-	      if(cq->Keyword=="cpg")
+	      if(Keyword=="cpg")
 		  {
-		  ChangeCpTranslator(cq);
+		  ChangeCpTranslator(this);
 		  break;
 		  }
-	      if(cq->Keyword=="emdash")
+	      if(Keyword=="emdash")
 		  {
-		  CharacterStr(cq,Ext_chr_str(151, cq, cq->Unicode)); break;
+		  CharacterStr(this,Ext_chr_str(151, this, Unicode)); break;
 		  }
-	      if(cq->Keyword=="endash")
+	      if(Keyword=="endash")
 		  {
-		  CharacterStr(cq,Ext_chr_str(150, cq, cq->Unicode)); break;
+		  CharacterStr(this,Ext_chr_str(150, this, Unicode)); break;
 		  }
-	      if(cq->Keyword=="f")
+	      if(Keyword=="f")
 		  {
-		  if(!cq->isParam) cq->lParam=0;
-		  const char *FX=cq->FontTable[cq->lParam];
+		  if(!isParam) lParam=0;
+		  const char *FX=FontTable[lParam];
 		  int Len=StrLen(FX);
 
-		  //cq->ConvertCpg = &Dummy;
+		  //ConvertCpg = &Dummy;
 		  if(Len>3)
 		    {
 		    if(FX[Len-3]==' ' && FX[Len-2]=='C' && FX[Len-1]=='E')
 		      {
-		      cq->Parameter="1250";
-		      ChangeCpTranslator(cq);
+		      Parameter="1250";
+		      ChangeCpTranslator(this);
 		      }
 		    }
-		  sprintf(cq->ObjType,"Font:%ld",cq->lParam);
+		  sprintf(ObjType,"Font:%ld",lParam);
 		  break;
 		  }
-	      if(cq->Keyword=="fonttbl")
+	      if(Keyword=="fonttbl")
 		  {
-		  FontTableRTF(cq);break;
+		  FontTableRTF(this); break;
 		  }
-	      if(cq->Keyword=="footer")
+	      if(Keyword=="footer")
 		  {
-		  HeaderFooterRTF(cq,6);break;		// 0110b
+		  HeaderFooterRTF(this,6); break;		// 0110b
 		  }
-	      if(cq->Keyword=="footerl")
+	      if(Keyword=="footerl")
 		  {
-		  HeaderFooterRTF(cq,0xE);break;	// 1110b
+		  HeaderFooterRTF(this,0xE); break;	// 1110b
 		  }
-	      if(cq->Keyword=="footerr")
+	      if(Keyword=="footerr")
 		  {
-		  HeaderFooterRTF(cq,0xA);break;	// 1010b
+		  HeaderFooterRTF(this,0xA); break;	// 1010b
 		  }
-	      if(cq->Keyword=="footnote")
+	      if(Keyword=="footnote")
 		  {
-		  FootnoteRTF(cq);break;
+		  FootnoteRTF(this);break;
 		  }
-	       if(cq->Keyword=="green")
+	       if(Keyword=="green")
 		  {
-		  if(!cq->isParam) cq->lParam=0;
-		  cq->NewRGB.G=cq->lParam;
+		  if(!isParam) lParam=0;
+		  NewRGB.G=lParam;
 		  break;
 		  }
-	      if(cq->Keyword=="header")
+	      if(Keyword=="header")
 		  {
-		  HeaderFooterRTF(cq,4);break;		// 0100b
+		  HeaderFooterRTF(this,4);break;		// 0100b
 		  }
-	      if(cq->Keyword=="headerl")
+	      if(Keyword=="headerl")
 		  {
-		  HeaderFooterRTF(cq,0xC);break;	// 1100b
+		  HeaderFooterRTF(this,0xC);break;	// 1100b
 		  }
-	      if(cq->Keyword=="headerr")
+	      if(Keyword=="headerr")
 		  {
-		  HeaderFooterRTF(cq,8);break;		// 1000b
+		  HeaderFooterRTF(this,8);break;		// 1000b
 		  }
-	      if(cq->Keyword=="highlight")
+	      if(Keyword=="highlight")
 		  {
-		  if(!cq->isParam)
-		    if(cq->lParam<=16 && cq->lParam>=1)
-			cq->NewRGB=RHT_Highlight[cq->lParam];
+		  if(!isParam)
+		    if(lParam<=16 && lParam>=1)
+			NewRGB=RHT_Highlight[lParam];
 		  break;
 		  }
-	      if(cq->Keyword=='i')
+	      if(Keyword=='i')
 		  {
-		  if(!cq->isParam) cq->lParam=1;
-		  if(cq->lParam) AttrOn(cq->attr,8);	/* Start italic */
-			    else AttrOff(cq,8);		/* End italic */
+		  if(!isParam) lParam=1;
+		  if(lParam) AttrOn(attr,8);	/* Start italic */
+			    else AttrOff(this,8);		/* End italic */
 		  break;
 		  }
-	      if(cq->Keyword=="leveltext" || cq->Keyword=="levelnumbers")
+	      if(Keyword=="leveltext" || Keyword=="levelnumbers")
 		  {
-		  if(cq->rds==rdsNorm) cq->rds=rdsSkip;	//toss garbage after level commands
+		  if(rds==rdsNorm) rds=rdsSkip;	//toss garbage after level commands
 		  break;
 		  }
-	      if(cq->Keyword=="li")
+	      if(Keyword=="li")
 		  {
-		  cq->pap.xaLeft=cq->isParam?cq->lParam:0;
+		  pap.xaLeft=isParam?lParam:0;
 		  break;
 		  }
-	      if(cq->Keyword=="listname")
+	      if(Keyword=="listname")
 		  {
-		  if(cq->rds==rdsNorm) cq->rds=rdsSkip;	//toss garbage after listname command
+		  if(rds==rdsNorm) rds=rdsSkip;	//toss garbage after listname command
 		  break;
 		  }
-	      if(cq->Keyword=="lquote")
+	      if(Keyword=="lquote")
 		  {
-		  CharacterStr(cq,Ext_chr_str(145, cq, cq->Unicode)); break;
+		  CharacterStr(this,Ext_chr_str(145, this, Unicode)); break;
 		  }
-	      if(cq->Keyword=="ldblquote")
+	      if(Keyword=="ldblquote")
 		  {
-		  CharacterStr(cq,Ext_chr_str(147, cq, cq->Unicode)); break;
+		  CharacterStr(this,Ext_chr_str(147, this, Unicode)); break;
 		  }
-	      if(cq->Keyword=="lang")
+	      if(Keyword=="lang")
 		  {
-		  LanguageRTF(cq);break;
+		  LanguageRTF(this); break;
 		  }
-	      if(cq->Keyword=="line")
+	      if(Keyword=="line")
 		  {
-		  Terminate_Line(cq,'h');		/* Hard line */
+		  Terminate_Line(this,'h');		/* Hard line */
 		  break;
 		  }
-	      if(cq->Keyword=="outl")
+	      if(Keyword=="outl")
 		  {
-		  if(cq->lParam) AttrOn(cq->attr,7);	/* Start underline */
-			    else AttrOff(cq,7);		/* End underline */
+		  if(lParam) AttrOn(attr,7);	/* Start underline */
+			    else AttrOff(this,7);		/* End underline */
 		  break;
 		  }
-	      if(cq->Keyword=="page")
+	      if(Keyword=="page")
 		  {
-		  Terminate_Line(cq,'P');		/* Hard page */
+		  Terminate_Line(this,'P');		/* Hard page */
 		  break;
 		  }
-	      if(cq->Keyword=="par")
+	      if(Keyword=="par")
 		  {
-		  if(cq->char_on_line) Terminate_Line(cq, 'h');	/* Hard return */
-		  Terminate_Line(cq, 'h');
+		  if(char_on_line) Terminate_Line(this, 'h');	/* Hard return */
+		  Terminate_Line(this, 'h');
 		  break;
 		  }
-	      if(cq->Keyword=="pard")
+	      if(Keyword=="pard")
 		  {
-		  if(cq->char_on_line) Terminate_Line(cq, 'h');	/* Hard return */
-		  cq->envir=' '; 			/*Finish any enviromnet opened*/
+		  if(char_on_line) Terminate_Line(this, 'h');	/* Hard return */
+		  envir=' '; 			/*Finish any enviromnet opened*/
 		  break;
 		  }
-	      if(cq->Keyword=="pc")
+	      if(Keyword=="pc")
 		  {
-		  cq->Parameter="437";
-		  ChangeCpTranslator(cq);
+		  Parameter="437";
+		  ChangeCpTranslator(this);
 		  break;
 		  }
-	      if(cq->Keyword=="pca")
+	      if(Keyword=="pca")
 		  {
-		  cq->Parameter="850";
-		  ChangeCpTranslator(cq);
+		  Parameter="850";
+		  ChangeCpTranslator(this);
 		  break;
 		  }
-	      if(cq->Keyword=="pict")
+	      if(Keyword=="pict")
 		  {
-		  PictureRTF(cq);  break;
+		  PictureRTF(this);  break;
 		  }
-	      if(cq->Keyword=="plain")
+	      if(Keyword=="plain")
 		  {
-		  AttrOff(cq,8);
-		  AttrOff(cq,9);
-		  AttrOff(cq,12);	/* End boldface */
-		  AttrOff(cq,13);
-		  AttrOff(cq,14);	/* End underline */
+		  AttrOff(this,8);
+		  AttrOff(this,9);
+		  AttrOff(this,12);	/* End boldface */
+		  AttrOff(this,13);
+		  AttrOff(this,14);	/* End underline */
 		  break;
 		  }
-	      if(cq->Keyword=="qc")
+	      if(Keyword=="qc")
 		  {
-		  Justification(cq,0x82);
+		  Justification(this,0x82);
 		  break;
 		  }
-	      if(cq->Keyword=="qj")
+	      if(Keyword=="qj")
 		  {
-		  Justification(cq,0x81);
+		  Justification(this,0x81);
 		  break;
 		  }
-	      if(cq->Keyword=="ql")
+	      if(Keyword=="ql")
 		  {
-		  Justification(cq,0x80);
+		  Justification(this,0x80);
 		  break;
 		  }
-	      if(cq->Keyword=="qr")
+	      if(Keyword=="qr")
 		  {
-		  Justification(cq,0x83);
+		  Justification(this,0x83);
 		  break;
 		  }
-	      if(cq->Keyword=="red")
+	      if(Keyword=="red")
 		  {
-		  if(!cq->isParam) cq->lParam=0;
-		  cq->NewRGB.R=cq->lParam;
+		  if(!isParam) lParam=0;
+		  NewRGB.R=lParam;
 		  break;
 		  }
-	      if(cq->Keyword=="rquote")
+	      if(Keyword=="rquote")
 		  {
-		  CharacterStr(cq,Ext_chr_str(146, cq, cq->Unicode)); break;
+		  CharacterStr(this,Ext_chr_str(146, this, Unicode)); break;
 		  }
-	      if(cq->Keyword=="rdblquote")
+	      if(Keyword=="rdblquote")
 		  {
-		  CharacterStr(cq,Ext_chr_str(148, cq, cq->Unicode)); break;
+		  CharacterStr(this,Ext_chr_str(148, this, Unicode)); break;
 		  }
-	      if(cq->Keyword=="scaps")
+	      if(Keyword=="scaps")
 		  {
-		  if(!cq->isParam) cq->lParam=1;
-		  if(cq->lParam) {AttrOn(cq->attr,15);strcpy(cq->ObjType, "smcap");}	/* Start small capitals */
-			    else {AttrOff(cq,15);strcpy(cq->ObjType, "~smcap");}	/* End small capitals */
+		  if(!isParam) lParam=1;
+		  if(lParam) {AttrOn(attr,15);strcpy(ObjType, "smcap");}	/* Start small capitals */
+			    else {AttrOff(this,15);strcpy(ObjType, "~smcap");}	/* End small capitals */
 		  break;
 		  }
-	      if(cq->Keyword=="sectd")
+	      if(Keyword=="sectd")
 		  {
-		  if(cq->Columns>1) Column(cq,1);	/*Reset number of columns to 1*/
+		  if(Columns>1) Column(this,1);	/*Reset number of columns to 1*/
 		  break;
 		  }
-	      if(cq->Keyword=="shad")
+	      if(Keyword=="shad")
 		  {
-		  if(cq->lParam) {AttrOn(cq->attr,9);strcpy(cq->ObjType, "shad");}  /* Start shadow */
-			    else {AttrOff(cq,9);strcpy(cq->ObjType, "~shad");}	   /* End shadow */
+		  if(lParam) {AttrOn(attr,9);strcpy(ObjType, "shad");}  /* Start shadow */
+			    else {AttrOff(this,9);strcpy(ObjType, "~shad");}	   /* End shadow */
 		  break;
 		  }
-	      if(cq->Keyword=="softpage")
+	      if(Keyword=="softpage")
 		  {
-		  Terminate_Line(cq,'p');		/* Soft page */
+		  Terminate_Line(this,'p');		/* Soft page */
 		  break;
 		  }
-	      if(cq->Keyword=="softline")
+	      if(Keyword=="softline")
 		  {
-		  Terminate_Line(cq,'s');		/* Soft line break */
+		  Terminate_Line(this,'s');		/* Soft line break */
 		  break;
 		  }
-	      if(cq->Keyword=="strike")
+	      if(Keyword=="strike")
 		  {
-		  if(cq->lParam) {AttrOn(cq->attr,13);strcpy(cq->ObjType, "stkout");} /* Start strike out */
-			    else {AttrOff(cq,13);strcpy(cq->ObjType, "~stkout");}     /* End strike out */
+		  if(lParam) {AttrOn(attr,13);strcpy(ObjType, "stkout");} /* Start strike out */
+			    else {AttrOff(this,13);strcpy(ObjType, "~stkout");}     /* End strike out */
 		  break;
 		  }
-	      if(cq->Keyword=="sub")
+	      if(Keyword=="sub")
 		  {
-		  if(!cq->isParam) cq->lParam=1;
-		  if(cq->lParam) AttrOn(cq->attr,6);	/* Start subscript */
-			    else AttrOff(cq,6);		/* End subscript */
+		  if(!isParam) lParam=1;
+		  if(lParam) AttrOn(attr,6);	/* Start subscript */
+			    else AttrOff(this,6);		/* End subscript */
 		  break;
 		  }
-	      if(cq->Keyword=="super")
+	      if(Keyword=="super")
 		  {
-		  if(!cq->isParam) cq->lParam=1;
-		  if(cq->lParam) AttrOn(cq->attr,5);	/* Start superscript */
-			    else AttrOff(cq,5);		/* End superscript */
+		  if(!isParam) lParam=1;
+		  if(lParam) AttrOn(attr,5);	/* Start superscript */
+			    else AttrOff(this,5);		/* End superscript */
 		  break;
 		  }
-	      if(cq->Keyword=="tab")
+	      if(Keyword=="tab")
 		  {
-		  fputc(' ',cq->strip);
+		  fputc(' ',strip);
 		  break;
 		  }
-	      if(cq->Keyword=='u')
+	      if(Keyword=='u')
 		  {
-		  UnicodeSymbol(cq);
+		  UnicodeSymbol(this);
 		  break;
 		  }
-	      if(cq->Keyword=="ul")
+	      if(Keyword=="ul")
 		  {
-		  if(!cq->isParam) cq->lParam=1;
-		  if(cq->lParam) AttrOn(cq->attr,14);	/* Start underline */
-			    else AttrOff(cq,14);	/* End underline */
+		  if(!isParam) lParam=1;
+		  if(lParam) AttrOn(attr,14);	/* Start underline */
+			    else AttrOff(this,14);	/* End underline */
 		  break;
 		  }
-	      if(cq->Keyword=="uldb")
+	      if(Keyword=="uldb")
 		  {
-		  if(!cq->isParam) cq->lParam=1;
-		  if(cq->lParam) AttrOn(cq->attr,11);	/* Start double underline */
-			    else AttrOff(cq,11);	/* End double underline */
+		  if(!isParam) lParam=1;
+		  if(lParam) AttrOn(attr,11);	/* Start double underline */
+			    else AttrOff(this,11);	/* End double underline */
 		  break;
 		  }
-	      if(cq->Keyword=="ulnone")
+	      if(Keyword=="ulnone")
 		  {
-		  AttrOff(cq,14); AttrOff(cq,11);	/* End of all underlines */
+		  AttrOff(this,14); AttrOff(this,11);	/* End of all underlines */
 		  break;
 		  }
-	      if(cq->Keyword=="xe")
+	      if(Keyword=="xe")
 		  {
-		  IndexRTF(cq);
+		  IndexRTF(this);
 		  break;
 		  }
 
-	      *(cq->ObjType)='!';
-	      ecTranslateKeyword(cq,cq->Keyword(), cq->lParam, cq->isParam); //keyword+arg
+	      *(ObjType)='!';
+	      ecTranslateKeyword(Keyword(), lParam, isParam); //keyword+arg
 
 	      break;
-     case 205:if((ec = ecParseChar(cq,cq->by)) != ecOK)	// character;
+     case 205:if((ec = ecParseChar(by)) != ecOK)	// character;
 			return ec;
 	      break;
-     case 206:if((ec = ecParseChar(cq,cq->by)) != ecOK)	// HEX
+     case 206:if((ec = ecParseChar(by)) != ecOK)	// HEX
 			    return ec;
 	      break;
      }
 
-
 RTFnext:
-	  if (cq->log != NULL)
+	  if (log != NULL)
     {   /**/
-    //fprintf(cq->log," %d ",cq->rds);
+    //fprintf(log," %d ",rds);
     switch(KeywordType)
       {
       case 205: case 206:
-	     if (cq->by >= ' ' && cq->by <= 'z')
-		putc(cq->by, cq->log);
+	     if (by >= ' ' && by <= 'z')
+		putc(by, log);
 	     break;
       case 0: case 1: case 2: case 3:
-	     fprintf(cq->log,"0x%2X ",cq->by);
-		putc(cq->by, cq->log);
+	     fprintf(log,"0x%2X ",by);
+		putc(by, log);
 	     break;
       default:
-	     if(!cq->Keyword.isEmpty())
+	     if(!Keyword.isEmpty())
 		{
 		char *Str;
-		fprintf(cq->log, "\n%*s[\\%s",
-			cq->cGroup+cq->recursion * 2,
-			*cq->ObjType=='!'?"!":"",cq->Keyword());
-		if(cq->isParam) fprintf(cq->log,"%ld",cq->lParam);
-		if(*cq->ObjType)
+		fprintf(log, "\n%*s[\\%s",
+			cGroup+recursion * 2,
+			*ObjType=='!'?"!":"",Keyword());
+		if(isParam) fprintf(log,"%ld",lParam);
+		if(*ObjType)
 		  {
-		  Str=cq->ObjType;
+		  Str=ObjType;
 		  if(*Str=='!') Str++;
 		  if(*Str=='\\') Str++;
-		  if(cq->Keyword != Str) fprintf(cq->log," %s",Str);
+		  if(Keyword != Str) fprintf(log," %s",Str);
 		  }
-		fprintf(cq->log,"] ");
-	fprintf(cq->log," rds=%d fSkipDestIfUnk=%d",cq->rds,cq->fSkipDestIfUnk);
+		fprintf(log,"] ");
+	fprintf(log," rds=%d fSkipDestIfUnk=%d",rds,fSkipDestIfUnk);
 	}
-//	     else putc(cq->by, cq->log);
+//	     else putc(by, log);
       }
     }
 
-  cq->ActualPos = ftell(cq->wpd);
+  ActualPos = ftell(wpd);
   return ecOK;
 }
 
@@ -2038,7 +2075,7 @@ uint32_t fsize;
 	      perc.Actualise(ActualPos);
       by=0;
 
-      if(ProcessKeyRTF(this) != ecOK) break;
+      if(ProcessKeyRTF() != ecOK) break;
       }
 
   if(err!=NULL)
@@ -2063,7 +2100,7 @@ uint32_t WChar;
 
  if(CharReader==NULL) return;  //a serious problem occured
 
- cq->ConvertCpg=GetTranslator("unicodeTOinternal");
+ cq->ConvertCpg = GetTranslator("unicodeTOinternal");
 
  fsize = FileSize(cq->wpd);
  cq->ActualPos = ftell(cq->wpd);
