@@ -41,6 +41,7 @@
 
 extern list HTMLChars;
 int SavePictureEPS(const char *Name, const Image &Img);
+void CheckOversizedImage(Image *PImg);
 
 
 class ForwardHolder: public VectorObject
@@ -223,7 +224,7 @@ ImplementReader(SVG,".SVG")
    LoadPictureSVG,
    NULL);
 
-#define SVGVersion "0.6"
+#define SVGVersion "0.7"
 
 
 void TconvertedPass1_SVG::EraseObjCache(void)
@@ -1082,6 +1083,8 @@ float stroke_width;
   if(!GetProp("y2",Points[3])) goto ExitErr;
   
   {
+    UpdateBBox(bbx,0, Points[0], Points[1], Points[2]-Points[0], Points[3]-Points[1]);
+
     VectorLine *pVecLine = new VectorLine(Points, 2); Points=NULL;
     pVecLine->AttribFromPSS(PSS);
     GetStyle(pVecLine,NULL);
@@ -1117,8 +1120,8 @@ RGB_Record FillColor;
     return;
   }
 
-//  PositionX = (*pPoints)[Close?0:(2*n-2)];
-//  PositionY = (*pPoints)[Close?1:(2*n-1)];
+  PositionX = (*pPoints)[2*n-2];
+  PositionY = (*pPoints)[2*n-1];
   for(i=0; i<n; i++)
   {
     if(Tx) Tx->ApplyTransform((*pPoints)[2*i], (*pPoints)[2*i+1]);
@@ -1140,6 +1143,8 @@ RGB_Record FillColor;
     //pVecLine->AttribFromPSS(PSS);
   }
   pVecLine->AttribFromPSS(PSS);
+  GetStyle(pVecLine,NULL);		// TODO: This should be reworked.
+
   if(pVecLine->LineStyle==0) pVecLine->LineStyle=1;
 
   n = 0;
@@ -1185,6 +1190,7 @@ float stroke_width;
 
   VectorCurve *pVecCurve = new VectorCurve(*pPoints, 3*n+1); n=0;
   *pPoints = NULL;
+  GetStyle(pVecCurve,NULL);
   pVecCurve->AttribFromPSS(PSS);
   if(GetProp("stroke-width",stroke_width))
   {
@@ -1196,7 +1202,7 @@ float stroke_width;
   if(GetColor(pVecCurve->FillColor,FILL_COLOR))
   {
     if(pVecCurve->BrushStyle==FILL_NONE) pVecCurve->BrushStyle=FILL_SOLID;
-    pVecCurve->Filled = true;
+    //pVecCurve->Filled = true;
   }
 
   pVecCurve->Close = Close;
@@ -1351,11 +1357,14 @@ int n, i;
 const char *StrMovements;
 float PositionOffsetX = 0;
 float PositionOffsetY = 0;
+//float ObjPositionX = PositionX;
+//float ObjPositionY = PositionY;
 bool isCurve = false;
 bool FirstCommand = true;
 char LastCommand = 0;
 AbstractTransformXY *Tx = NULL;
 int SegmentCount = 0;
+VectorList VectListIn;
 
   n = 0;
   if((i=TAG_Args IN "d")<0) goto ExitErr;
@@ -1363,10 +1372,12 @@ int SegmentCount = 0;
   if(StrMovements==NULL) goto ExitErr;
 
   Tx = getTransform();
+  VectListIn.Swap(VectList);
   while(*StrMovements != 0)
   {
     while(isspace(*StrMovements)) StrMovements++;
-    switch((isdigit(*StrMovements) || *StrMovements=='.' || *StrMovements=='-' || *StrMovements==0) ? LastCommand : *StrMovements++)
+    if(*StrMovements==0) break;
+    switch((isdigit(*StrMovements) || *StrMovements=='.' || *StrMovements=='-') ? LastCommand : *StrMovements++)
     {
       case 'M':			//move to.
         if(n>0) SegmentCount++;
@@ -1383,6 +1394,8 @@ int SegmentCount = 0;
           ReadFloat(&StrMovements, PositionY);
         }
         PositionOffsetX = PositionOffsetY = 0;
+/*      ObjPositionX = PositionX;
+        ObjPositionY = PositionY; */
         FirstCommand = false;
         break;
 
@@ -1392,6 +1405,8 @@ int SegmentCount = 0;
           ClosePathCurve(&Points,n,false,Tx);
         else
           ClosePathLine(&Points,n,false,Tx);
+//        ObjPositionX = 0;
+//        ObjPositionY = 0;
 
         ReadFloat(&StrMovements, PositionOffsetX);
         if(FirstCommand)
@@ -1427,23 +1442,23 @@ int SegmentCount = 0;
           isCurve = false;
         }
 
-          if(Points==NULL)
-          {
-            Points = (float*)malloc(4*sizeof(float));
-            if(!Points) goto ExitErr;
-            Points[0]=PositionX; Points[1]=PositionY;
-            n = 2;
-          }
-          else
-          {
-            n++;
-            Points = (float*)realloc(Points,2*n*sizeof(float));
-            if(Points==NULL) goto ExitErr;
-          }
+        if(Points==NULL)
+        {
+          Points = (float*)malloc(4*sizeof(float));
+          if(!Points) goto ExitErr;
+          Points[0]=PositionX; Points[1]=PositionY;
+          n = 2;
+        }
+        else
+        {
+          n++;
+          Points = (float*)realloc(Points,2*n*sizeof(float));
+          if(Points==NULL) goto ExitErr;
+        }
 
-          ReadFloat(&StrMovements, Points[2*n-2]);
-          Points[2*n-2] += PositionOffsetX;
-          Points[2*n-1] = PositionY + PositionOffsetY;
+        ReadFloat(&StrMovements, Points[2*n-2]);
+        Points[2*n-2] += PositionOffsetX;
+        Points[2*n-1] = PositionY + PositionOffsetY;
         break;
 
      case 'h':		// horizontal relative line to.
@@ -1455,24 +1470,24 @@ int SegmentCount = 0;
           isCurve = false;
         }
 
-          if(Points==NULL)
-          {
-            Points = (float*)malloc(4*sizeof(float));
-            if(!Points) goto ExitErr;
-            Points[0]=PositionX; Points[1]=PositionY;
-            n = 2;
-          }
-          else
-          {
-            n++;
-            Points = (float*)realloc(Points,2*n*sizeof(float));
-            if(Points==NULL) goto ExitErr;
-          }
+        if(Points==NULL)
+        {
+          Points = (float*)malloc(4*sizeof(float));
+          if(!Points) goto ExitErr;
+          Points[0]=PositionX; Points[1]=PositionY;
+          n = 2;
+        }
+        else
+        {
+          n++;
+          Points = (float*)realloc(Points,2*n*sizeof(float));
+          if(Points==NULL) goto ExitErr;
+        }
 
-          ReadFloat(&StrMovements, val);
-          PositionX += val;
-          Points[2*n-2] = PositionX;
-          Points[2*n-1] = PositionY;
+        ReadFloat(&StrMovements, val);
+        PositionX += val;
+        Points[2*n-2] = PositionX;
+        Points[2*n-1] = PositionY;
         break;
 
      case 'V':		//vertical line to.
@@ -1784,7 +1799,17 @@ int SegmentCount = 0;
         if(isCurve)
             ClosePathCurve(&Points, n, SegmentCount<=0, Tx);
         else
-            ClosePathLine(&Points, n, SegmentCount<=0, Tx);
+        {
+/*        if(Points!=NULL && n>0)
+          {
+            n++;
+            Points = (float*)realloc(Points,2*n*sizeof(float));
+            if(Points==NULL) goto ExitErr;
+            Points[2*n-2] = ObjPositionX+PositionOffsetX;
+            Points[2*n-1] = ObjPositionY+PositionOffsetY;
+          } */
+          ClosePathLine(&Points, n, SegmentCount<=0, Tx);
+        }
         SegmentCount = 0;
         break;
 
@@ -1807,6 +1832,33 @@ int SegmentCount = 0;
   else
     ClosePathLine(&Points,n,false,Tx);
 
+  VectListIn.Swap(VectList);
+  if(VectListIn.FirstObject!=NULL)
+  {
+    VectorPath *pVectPath = new VectorPath;
+    if(pVectPath)
+    {
+      GetStyle(pVectPath,pVectPath);
+      float stroke_width;
+      if(GetProp("stroke-width",stroke_width))
+      {
+        pVectPath->PenWidth = stroke_width;
+      }
+      if(GetColor(pVectPath->FillColor,FILL_COLOR))
+      {
+        if(pVectPath->BrushStyle==FILL_NONE) pVectPath->BrushStyle=FILL_SOLID;
+        //pVectPath->Filled = true;
+      }
+      GetColor(pVectPath->LineColor);
+      GetLineCap(pVectPath->LineCap);
+      GetLineJoin(pVectPath->LineJoin);
+      //pVectPath->Close = Close;
+
+      pVectPath->Swap(VectListIn);
+      VectList.AddObject(pVectPath);
+    }
+  }
+
   strcpy(ObjType,ObjName+1);
   if(Tx) delete Tx;
   return;
@@ -2290,6 +2342,8 @@ int RetVal = 0;
       if(pImg->Raster!=NULL)
         ReducePalette(pImg,256);
 
+    CheckOversizedImage(&Img);
+
     string NewFilename = MergePaths(OutputDir,RelativeFigDir);
     string wpd_cut = CutFileName(wpd_filename);
     if(recursion==0 && length(wpd_cut)>0)
