@@ -436,7 +436,17 @@ string TeX_RelativeFigDir;
   if(Columns==2)fprintf(this->LaTeX, "\\onecolumn\n");
   if (Index)    fprintf(this->LaTeX, "\\makeindex\n");
   if(FancyHdr>=1) fprintf(this->LaTeX, "\\pagestyle{fancy}\\renewcommand{\\headrulewidth}{0pt}\n\\fancyfoot{}\\fancyhead{}\n");
-  if((InputPS&1)==1) TeX_RelativeFigDir=replacesubstring(RelativeFigDir,"\\","/");
+  if((InputPS&1)==1)
+  {
+    if(AbsolutePath(RelativeFigDir()) && !strncmp(OutputDir(),RelativeFigDir(),OutputDir.length()))
+    {
+      TeX_RelativeFigDir = "./";
+      TeX_RelativeFigDir += RelativeFigDir()+ OutputDir.length();
+      TeX_RelativeFigDir = replacesubstring(TeX_RelativeFigDir,"\\","/");
+    }
+    else
+        TeX_RelativeFigDir = replacesubstring(RelativeFigDir,"\\","/");
+  }
   if(InputPS==(IMG_InputPS|1) || InputPS==(IMG_epsfig|1) || InputPS==(IMG_graphics|1) || InputPS==(IMG_graphicx|1))
        fprintf(this->LaTeX, "\\newcommand{\\FigDir}{%s}\n",TeX_RelativeFigDir());
 
