@@ -315,7 +315,8 @@ void Sys_Variable(void)
 {
 string var;
 char **argv;
-int argc,i;
+int argc;
+unsigned i;
 char typ,oldtyp;
 
  argc=0;
@@ -644,7 +645,8 @@ static int DetectT602(FILE *text, FFormatDetect & iFFD)
 {
 long OldFilePos;
 string Command;
-int commands=0,len;
+int commands=0;
+unsigned len;
 
   iFFD.DocumentType = "Text 602";
   iFFD.Extension = iFFD.Converter = "T602";
@@ -662,7 +664,7 @@ HdrEnd:	if(commands<3) goto NoT602;
 	}
     if(Command[0]!='@')
 	goto HdrEnd;
-    for(len=1;len<length(Command);len++)
+    for(len=1; len<length(Command); len++)
        {
        if(isspace(Command[len])) break; 
        }
@@ -1955,6 +1957,12 @@ int p;
 		ExtendedCheck = false;
 		continue;
 		}
+	if(!strcmp(name, "shrink-images")||!strcmp(name, "shrinkimages"))
+		{
+		CheckOversize = -1;
+		continue;
+		}
+
 	if(!strcmp(name, "texchars")||!strcmp(name, "TeXchars")) /*-no-texchars*/
 		{
 		TexChars = false;
@@ -1981,6 +1989,12 @@ int p;
 	   OptimizeSection = true;
 	   continue;
 	   }
+
+      if(!strcmp(name, "shrink-images")||!strcmp(name, "shrinkimages"))
+	   {
+	   CheckOversize = 1;
+	   continue;
+	   }
 		
       if (!strncmp(name, "rus-yo",6))
 	    {
