@@ -196,8 +196,11 @@ const char *UnitName="";
 /** This function handles error situation. */
 void RunError(int ExitCode, const char *s, const void *arg)
 {
+#ifdef _REENTRANT
+  AbortJobs();
+#endif
   putchar('\n');
-  switch (ExitCode)
+  switch(ExitCode)
     {
     case -2:
     case -1:   ExitCode=0;	/*silently exit program*/
@@ -323,7 +326,7 @@ static bool printed=false;
 }
 
 
-static char StyleUsed(SBYTE u)
+static char StyleUsed(int8_t u)
 {
   if(u<=-1) return '-';
   if(u>=+1) return '+';
@@ -588,12 +591,12 @@ void AskUser(void)
 static void CheckCompiler(void)
 {
 char str[20];
- if((sizeof(__u8)!=1)||(sizeof(__u16)!=2)||(sizeof(__u32)!=4)||
-   (sizeof(__s8)!=1)||(sizeof(__s16)!=2)||(sizeof(__s32)!=4))
+ if((sizeof(uint8_t)!=1)||(sizeof(uint16_t)!=2)||(sizeof(uint32_t)!=4)||
+   (sizeof(int8_t)!=1)||(sizeof(int16_t)!=2)||(sizeof(int32_t)!=4))
 	{
 	Heading();
-	fprintf(err,_("\nFatal: Code was badly compiled. sizeof(__u8)=%d sizeof(__u16)=%d sizeof(__u32)=%d\nCheck typedfs.h !!!!!"),
-           (int)sizeof(__u8), (int)sizeof(__u16), (int)sizeof(__u32));	
+	fprintf(err,_("\nFatal: Code was badly compiled. sizeof(uint8_t)=%d sizeof(uint16_t)=%d sizeof(uint32_t)=%d\nCheck typedfs.h !!!!!"),
+           (int)sizeof(uint8_t), (int)sizeof(uint16_t), (int)sizeof(uint32_t));	
         AskUser();
 	}
   sprintf(str,"%4.3f",1234.567);
@@ -692,7 +695,7 @@ TconvertedPass1 *cqPass1;
   CheckOptions();
 
   if(LaTeX_Version>=0x209)
-    StyleOpCl = StyleOpCl3;    
+    StyleOpCl = StyleOpCl3;
   else    
     StyleOpCl = StyleOpCl2;
 
