@@ -17,8 +17,8 @@
 
 #define LineLength   80		/* Split lines after more than LineLength charcters */
 
-#define VersionWP2L	"4.3"
-#define VersionDate	"31 Oct 2023"  /* day (space) month (space) full year */
+#define VersionWP2L	"4.4"
+#define VersionDate	"26 Nov 2023"  /* day (space) month (space) full year */
 
 
 /** Constants for a flag InputPS */
@@ -37,6 +37,7 @@ extern int8_t Cyrillic, colors, EndNotes, FancyHdr, Columns, cjHebrew, InputPS,
 	 textcomp, Wasy, Accents, Amssymb, Arevmath, LaTeXsym, LongTable, Bbm, TIPA, fontenc,
 	 Rsfs, Ulem, pifont, PostScript, rus_yo, Rotate, Scalerel, LineNo, AmsMath,
          SaveWPG, mxedruli;
+extern signed char CheckOversize;
 extern int LaTeX_Version;
 extern signed char Verbosing;
 extern bool TexChars,ExtendedCheck,OptimizeSection,FixSpaces;
